from a10sdk.common.A10BaseClass import A10BaseClass


class Health(A10BaseClass):
    
    """Class Description::
    Configure health monitoring.

    Class health supports CRUD Operations and inherits from `common/A10BaseClass`.
    This class is the `"PARENT"` class for this module.`

    :param monitor_list: {"minItems": 1, "items": {"type": "monitor"}, "uniqueItems": true, "array": [{"required": ["name"], "properties": {"sample-threshold": {"description": "Number of samples in one epoch above which passive HC is enabled. If below or equal to the threshold, passive HC is disabled (Specify number of samples in one second (Default is 50). If the number of samples is 0, no action is taken)", "format": "number", "default": 50, "optional": true, "maximum": 10000, "minimum": 1, "type": "number"}, "override-ipv4": {"optional": true, "type": "string", "description": "Override implicitly inherited IPv4 address from target", "format": "ipv4-address"}, "retry": {"description": "Specify the Healthcheck Retries (Retry Count (default 3))", "format": "number", "optional": true, "maximum": 10, "minimum": 1, "default-depends-on": "health.global::retry", "type": "number"}, "name": {"description": "Monitor Name", "format": "string", "minLength": 1, "optional": false, "maxLength": 29, "type": "string"}, "strict-retry-on-server-err-resp": {"default": 0, "optional": true, "type": "number", "description": "Require strictly retry", "format": "flag"}, "passive-interval": {"description": "Interval to do manual health checking while in passive mode (Specify value in seconds (Default is 10 s))", "format": "number", "default": 10, "optional": true, "maximum": 180, "minimum": 1, "type": "number"}, "override-port": {"description": "Override implicitly inherited port from target (Port number (1-65534))", "format": "number", "type": "number", "maximum": 65534, "minimum": 1, "optional": true}, "up-retry": {"description": "Specify the Healthcheck Retries before declaring target up (Up-retry count (default 1))", "format": "number", "optional": true, "maximum": 10, "minimum": 1, "default-depends-on": "health.global::up-retry", "type": "number"}, "interval": {"description": "Specify the Healthcheck Interval (Interval Value, in seconds (default 5))", "format": "number", "optional": true, "maximum": 180, "minimum": 1, "default-depends-on": "health.global::interval", "type": "number"}, "passive": {"default": 0, "optional": true, "type": "number", "description": "Specify passive mode", "format": "flag"}, "override-ipv6": {"optional": true, "type": "string", "description": "Override implicitly inherited IPv6 address from target", "format": "ipv6-address"}, "timeout": {"description": "Specify the Healthcheck Timeout (Timeout Value, in seconds(default 5), Timeout should be less than or equal to interval)", "format": "number", "optional": true, "maximum": 180, "minimum": 1, "default-depends-on": "health.global::timeout", "type": "number"}, "threshold": {"description": "Threshold percentage above which passive mode is enabled (Specify percentage (Default is 75%))", "format": "number", "default": 75, "optional": true, "maximum": 100, "minimum": 0, "type": "number"}, "disable-after-down": {"default": 0, "optional": true, "type": "number", "description": "Disable the target if health check failed", "format": "flag"}, "method": {"type": "object", "properties": {"ftp": {"type": "object", "properties": {"ftp": {"default": 0, "type": "number", "description": "FTP type", "format": "flag"}, "ftp-password-string": {"minLength": 1, "maxLength": 31, "type": "string", "description": "Specify the user password, '' means empty passworddd", "format": "password"}, "ftp-password": {"default": 0, "type": "number", "description": "Specify the user password", "format": "flag"}, "ftp-port": {"description": "Specify FTP port (Specify port number, default is 21)", "format": "number", "default": 21, "maximum": 65534, "minimum": 1, "type": "number"}, "ftp-encrypted": {"type": "encrypted", "description": "Do NOT use this option manually. (This is an A10 reserved keyword.) (The ENCRYPTED password string)", "format": "encrypted"}, "ftp-username": {"minLength": 1, "maxLength": 31, "type": "string", "description": "Specify the username", "format": "string-rlx"}}}, "udp": {"type": "object", "properties": {"udp": {"default": 0, "type": "number", "description": "UDP type", "format": "flag"}, "udp-port": {"description": "Specify UDP port (Specify port number)", "minimum": 1, "type": "number", "maximum": 65534, "format": "number"}}}, "sip": {"type": "object", "properties": {"sip-port": {"description": "Specify the SIP port, default is 5060 (Port Number)", "format": "number", "default": 5060, "maximum": 65534, "minimum": 1, "type": "number"}, "expect-response-code": {"minLength": 1, "maxLength": 31, "type": "string", "description": "Specify accepted response codes (e.g. 200, 400-430, any) (Format is xxx,xxx-xxx,any (xxx between [100,899]))", "format": "string-rlx"}, "sip": {"default": 0, "type": "number", "description": "SIP type", "format": "flag"}, "sip-tcp": {"default": 0, "type": "number", "description": "Use TCP for transmission, default is UDP", "format": "flag"}, "register": {"default": 0, "type": "number", "description": "Send SIP REGISTER message, default is to send OPTION message", "format": "flag"}}}, "http": {"type": "object", "properties": {"http-kerberos-kdc": {"type": "object", "properties": {"http-kerberos-hostipv6": {"not": "http-kerberos-hostip", "type": "string", "description": "Server's IPV6 address", "format": "ipv6-address"}, "http-kerberos-port": {"description": "Specify the kdc port", "minimum": 1, "type": "number", "maximum": 65535, "format": "number"}, "http-kerberos-portv6": {"description": "Specify the kdc port", "minimum": 1, "type": "number", "maximum": 65535, "format": "number"}, "http-kerberos-hostip": {"description": "Kdc's hostname or IP address", "format": "host", "minLength": 1, "maxLength": 31, "not": "http-kerberos-hostipv6", "type": "string"}}}, "http-encrypted": {"type": "encrypted", "description": "Do NOT use this option manually. (This is an A10 reserved keyword.) (The ENCRYPTED password string)", "format": "encrypted"}, "http-host": {"minLength": 1, "maxLength": 63, "type": "string", "description": "Specify \"Host:\" header used in request (enclose IPv6 address in [])", "format": "string-rlx"}, "post-path": {"minLength": 1, "maxLength": 500, "type": "string", "description": "Specify URL path, default is \"/\"", "format": "string-rlx"}, "http": {"default": 0, "type": "number", "description": "HTTP type", "format": "flag"}, "post-type": {"enum": ["postdata", "postfile"], "type": "string", "description": "'postdata': Specify the HTTP post data; 'postfile': Specify the HTTP post data; ", "format": "enum"}, "http-password": {"default": 0, "type": "number", "description": "Specify the user password", "format": "flag"}, "http-url": {"default": 0, "type": "number", "description": "Specify URL string, default is GET /", "format": "flag"}, "http-expect": {"default": 0, "type": "number", "description": "Specify what you expect from the response message", "format": "flag"}, "http-kerberos-auth": {"default": 0, "type": "number", "description": "Http Kerberos Auth", "format": "flag"}, "url-path": {"minLength": 1, "maxLength": 500, "type": "string", "description": "Specify URL path, default is \"/\"", "format": "string-rlx"}, "url-type": {"enum": ["GET", "POST", "HEAD"], "type": "string", "description": "'GET': HTTP GET method; 'POST': HTTP POST method; 'HEAD': HTTP HEAD method; ", "format": "enum"}, "http-postdata": {"minLength": 1, "maxLength": 255, "type": "string", "description": "Specify the HTTP post data (Input post data here)", "format": "string-rlx"}, "http-username": {"minLength": 1, "maxLength": 31, "type": "string", "description": "Specify the username", "format": "string-rlx"}, "http-kerberos-realm": {"minLength": 1, "maxLength": 63, "type": "string", "description": "Specify realm of Kerberos server", "format": "string-rlx"}, "http-response-code": {"description": "Specify response code range (e.g. 200,400-430) (Format is xx,xx-xx (xx between [100, 899]))", "format": "string-rlx", "minLength": 1, "maxLength": 31, "not": "http-text", "type": "string"}, "http-maintenance-code": {"minLength": 1, "maxLength": 31, "type": "string", "description": "Specify response code for maintenance (Format is xx,xx-xx (xx between [100, 899]))", "format": "string-rlx"}, "http-text": {"description": "Specify text expected", "format": "string-rlx", "minLength": 1, "maxLength": 127, "not": "http-response-code", "type": "string"}, "http-postfile": {"minLength": 1, "maxLength": 31, "type": "string", "description": "Specify the HTTP post data (Input post data file name here)", "format": "string-rlx"}, "http-port": {"description": "Specify HTTP Port (Specify port number (default 80))", "format": "number", "default": 80, "maximum": 65534, "minimum": 1, "type": "number"}, "http-password-string": {"minLength": 1, "maxLength": 31, "type": "string", "description": "Specify password, '' means empty passworddd", "format": "password"}}}, "https": {"type": "object", "properties": {"https-kerberos-realm": {"minLength": 1, "maxLength": 63, "type": "string", "description": "Specify realm of Kerberos server", "format": "string-rlx"}, "post-type": {"enum": ["postdata", "postfile"], "type": "string", "description": "'postdata': Specify the HTTP post data; 'postfile': Specify the HTTP post data; ", "format": "enum"}, "url-path": {"minLength": 1, "maxLength": 500, "type": "string", "description": "Specify URL path, default is \"/\"", "format": "string-rlx"}, "https-username": {"minLength": 1, "maxLength": 31, "type": "string", "description": "Specify the username", "format": "string-rlx"}, "key-phrase": {"minLength": 1, "maxLength": 31, "type": "string", "description": "Password Phrase", "format": "password"}, "https-postdata": {"minLength": 1, "maxLength": 255, "type": "string", "description": "Specify the HTTP post data (Input post data here)", "format": "string-rlx"}, "https-key-encrypted": {"type": "encrypted", "description": "Do NOT use this option manually. (This is an A10 reserved keyword.) (The ENCRYPTED password string)", "format": "encrypted"}, "https-expect": {"default": 0, "type": "number", "description": "Specify what you expect from the response message", "format": "flag"}, "https": {"default": 0, "type": "number", "description": "HTTPS type", "format": "flag"}, "https-host": {"minLength": 1, "maxLength": 63, "type": "string", "description": "Specify \"Host:\" header used in request (enclose IPv6 address in [])", "format": "string-rlx"}, "key-pass-phrase": {"default": 0, "type": "number", "description": "Client private key password phrase", "format": "flag"}, "https-encrypted": {"type": "encrypted", "description": "Do NOT use this option manually. (This is an A10 reserved keyword.) (The ENCRYPTED password string)", "format": "encrypted"}, "url-type": {"enum": ["GET", "POST", "HEAD"], "type": "string", "description": "'GET': HTTP GET method; 'POST': HTTP POST method; 'HEAD': HTTP HEAD method; ", "format": "enum"}, "web-port": {"description": "Specify HTTPS port (Port Number (default 443))", "format": "number", "default": 443, "maximum": 65534, "minimum": 1, "type": "number"}, "disable-sslv2hello": {"default": 0, "type": "number", "description": "Disable SSLv2Hello for HTTPs", "format": "flag"}, "https-kerberos-kdc": {"type": "object", "properties": {"https-kerberos-portv6": {"description": "Specify the kdc port", "minimum": 1, "type": "number", "maximum": 65535, "format": "number"}, "https-kerberos-port": {"description": "Specify the kdc port", "minimum": 1, "type": "number", "maximum": 65535, "format": "number"}, "https-kerberos-hostip": {"description": "Kdc's hostname or IP address", "format": "host", "minLength": 1, "maxLength": 31, "not": "https-kerberos-hostipv6", "type": "string"}, "https-kerberos-hostipv6": {"not": "https-kerberos-hostip", "type": "string", "description": "Server's IPV6 address", "format": "ipv6-address"}}}, "key": {"minLength": 1, "maxLength": 255, "type": "string", "description": "Specify client private key (Key name)", "format": "string-rlx"}, "https-password-string": {"minLength": 1, "maxLength": 31, "type": "string", "description": "help Configure password, '' means empty passworddd", "format": "password"}, "post-path": {"minLength": 1, "maxLength": 500, "type": "string", "description": "Specify URL path, default is \"/\"", "format": "string-rlx"}, "https-postfile": {"minLength": 1, "maxLength": 31, "type": "string", "description": "Specify the HTTP post data (Input post data file name here)", "format": "string-rlx"}, "https-password": {"default": 0, "type": "number", "description": "Specify the user password", "format": "flag"}, "cert": {"minLength": 1, "maxLength": 255, "type": "string", "description": "Specify client certificate (Certificate name)", "format": "string-rlx"}, "https-text": {"description": "Specify text expected", "format": "string-rlx", "minLength": 1, "maxLength": 127, "not": "https-response-code", "type": "string"}, "https-response-code": {"description": "Specify response code range (e.g. 200,400-430) (Format is xx,xx-xx (xx between [100, 899])", "format": "string-rlx", "minLength": 1, "maxLength": 31, "not": "https-text", "type": "string"}, "https-kerberos-auth": {"default": 0, "type": "number", "description": "Https Kerberos Auth", "format": "flag"}, "https-maintenance-code": {"minLength": 1, "maxLength": 31, "type": "string", "description": "Specify response code for maintenance (Format is xx,xx-xx (xx between [100, 899])", "format": "string-rlx"}, "https-url": {"default": 0, "type": "number", "description": "Specify URL string, default is GET /", "format": "flag"}}}, "compound": {"type": "object", "properties": {"rpn-string": {"minLength": 1, "maxLength": 512, "type": "string", "description": "Enter Reverse Polish Notation, example: sub hm1 sub hm2 and", "format": "string-rlx"}, "compound": {"default": 0, "type": "number", "description": "Compound type", "format": "flag"}}}, "database": {"type": "object", "properties": {"db-send": {"minLength": 1, "maxLength": 63, "type": "string", "description": "Specify the SQL query", "format": "string-rlx"}, "db-password": {"default": 0, "type": "number", "description": "Specify the user password", "format": "flag"}, "database": {"default": 0, "type": "number", "description": "DATABASE type", "format": "flag"}, "db-receive": {"minLength": 1, "maxLength": 31, "type": "string", "description": "Specify the response string", "format": "string-rlx"}, "database-name": {"enum": ["mssql", "mysql", "oracle", "postgresql"], "type": "string", "description": "'mssql': Specify MSSQL database; 'mysql': Specify MySQL database; 'oracle': Specify Oracle database; 'postgresql': Specify PostgreSQL database; ", "format": "enum"}, "db-password-str": {"minLength": 1, "maxLength": 31, "type": "string", "description": "Configure password", "format": "password"}, "db-encrypted": {"type": "encrypted", "description": "Do NOT use this option manually. (This is an A10 reserved keyword.) (The ENCRYPTED password string)", "format": "encrypted"}, "db-column": {"description": "Specify the column number for receiving", "minimum": 1, "type": "number", "maximum": 10, "format": "number"}, "db-name": {"minLength": 1, "maxLength": 31, "type": "string", "description": "Specify the database name", "format": "string-rlx"}, "db-username": {"minLength": 1, "maxLength": 31, "type": "string", "description": "Specify the username", "format": "string-rlx"}, "db-row": {"description": "Specify the row number for receiving", "minimum": 1, "type": "number", "maximum": 10, "format": "number"}}}, "smtp": {"type": "object", "properties": {"smtp-port": {"description": "Specify SMTP port, default is 25 (Port Number (default 25))", "format": "number", "default": 25, "maximum": 65534, "minimum": 1, "type": "number"}, "smtp-domain": {"minLength": 1, "maxLength": 255, "type": "string", "description": "Specify domain name of 'helo' command", "format": "string"}, "smtp": {"default": 0, "type": "number", "description": "SMTP type", "format": "flag"}}}, "ntp": {"type": "object", "properties": {"ntp": {"default": 0, "type": "number", "description": "NTP type", "format": "flag"}, "ntp-port": {"description": "Specify the NTP port, default is 123 (Port Number (default 123))", "format": "number", "default": 123, "maximum": 65534, "minimum": 1, "type": "number"}}}, "rtsp": {"type": "object", "properties": {"rtsp-port": {"description": "Specify RTSP port, default is 554 (Port Number (default 554))", "format": "number", "default": 554, "maximum": 65534, "minimum": 1, "type": "number"}, "rtsp": {"default": 0, "type": "number", "description": "RTSP type", "format": "flag"}, "rtspurl": {"minLength": 1, "maxLength": 127, "type": "string", "description": "Specify URL string (Specify the path on the server)", "format": "string-rlx"}}}, "snmp": {"type": "object", "properties": {"snmp-port": {"description": "Specify SNMP port, default is 161 (Port Number)", "format": "number", "default": 161, "maximum": 65534, "minimum": 1, "type": "number"}, "operation": {"type": "object", "properties": {"oper-type": {"enum": ["getnext", "get"], "type": "string", "description": "'getnext': Get-Next-Request command; 'get': Get-Request command; ", "format": "enum"}}}, "oid": {"type": "object", "properties": {"mib": {"not": "asn", "enum": ["sysDescr", "sysUpTime", "sysName"], "type": "string", "description": "'sysDescr': The MIB-2 OID of system description, 1.1.0; 'sysUpTime': The MIB-2 OID of system up time, 1.3.0; 'sysName': The MIB-2 OID of system nume, 1.5.0; ", "format": "enum"}, "asn": {"description": "Specify the format in ASN.1 style", "format": "string-rlx", "minLength": 1, "maxLength": 128, "not": "mib", "type": "string"}}}, "snmp": {"default": 0, "type": "number", "description": "SNMP type", "format": "flag"}, "community": {"description": "Specify SNMP community, default is \"public\" (Community String)", "format": "string-rlx", "default": "public", "minLength": 1, "maxLength": 31, "type": "string"}}}, "tcp": {"type": "object", "properties": {"port-send": {"description": "Send a string to server (Specify the string)", "format": "string-rlx", "minLength": 1, "maxLength": 127, "not": "port-halfopen", "type": "string"}, "method-tcp": {"default": 0, "type": "number", "description": "TCP type", "format": "flag"}, "port-halfopen": {"default": 0, "not": "port-send", "type": "number", "description": "Set TCP SYN check", "format": "flag"}, "port-resp": {"type": "object", "properties": {"port-contains": {"minLength": 1, "maxLength": 127, "type": "string", "description": "Mark server up if response string contains another string (Specify the string)", "format": "string-rlx"}}}, "tcp-port": {"description": "Specify TCP port (Specify port number)", "minimum": 1, "type": "number", "maximum": 65534, "format": "number"}}}, "pop3": {"type": "object", "properties": {"pop3-password-string": {"minLength": 1, "maxLength": 31, "type": "string", "description": "Specify the user password, '' means empty passworddd", "format": "password"}, "pop3-password": {"default": 0, "type": "number", "description": "Specify the user password", "format": "flag"}, "pop3-username": {"minLength": 1, "maxLength": 31, "type": "string", "description": "Specify the username", "format": "string-rlx"}, "pop3-port": {"description": "Specify the POP3 port, default is 110 (Port Number (default 110))", "format": "number", "default": 110, "maximum": 65534, "minimum": 1, "type": "number"}, "pop3": {"default": 0, "type": "number", "description": "POP3 type", "format": "flag"}, "pop3-encrypted": {"type": "encrypted", "description": "Do NOT use this option manually. (This is an A10 reserved keyword.) (The ENCRYPTED password string)", "format": "encrypted"}}}, "radius": {"type": "object", "properties": {"radius-username": {"minLength": 1, "maxLength": 31, "type": "string", "description": "Specify the username", "format": "string-rlx"}, "radius-password-string": {"minLength": 1, "maxLength": 31, "type": "string", "description": "Configure password, '' means empty passworddd", "format": "password"}, "radius-encrypted": {"type": "encrypted", "description": "Do NOT use this option manually. (This is an A10 reserved keyword.) (The ENCRYPTED password string)", "format": "encrypted"}, "radius-response-code": {"minLength": 1, "maxLength": 31, "type": "string", "description": "Specify response code range (e.g. 2,4-7) (Format is xx,xx-xx (xx between [1, 13]))", "format": "string-rlx"}, "radius-expect": {"default": 0, "type": "number", "description": "Specify what you expect from the response message", "format": "flag"}, "radius": {"default": 0, "type": "number", "description": "RADIUS type", "format": "flag"}, "radius-secret": {"minLength": 1, "maxLength": 31, "type": "string", "description": "Specify the shared secret of RADIUS server (Shared Crypto Key)", "format": "string-rlx"}, "radius-password": {"default": 0, "type": "number", "description": "Specify the user password", "format": "flag"}, "radius-port": {"description": "Specify the RADIUS port, default is 1812 (Port number (default 1812))", "format": "number", "default": 1812, "maximum": 65534, "minimum": 1, "type": "number"}}}, "external": {"type": "object", "properties": {"ext-preference": {"default": 0, "type": "number", "description": "Get server's perference", "format": "flag"}, "ext-port": {"description": "Specify the server port (Port Number)", "minimum": 1, "type": "number", "maximum": 65534, "format": "number"}, "external": {"default": 0, "type": "number", "description": "EXTERNAL type", "format": "flag"}, "ext-arguments": {"minLength": 1, "maxLength": 127, "type": "string", "description": "Specify external application's arguments (Application arguments)", "format": "string-rlx"}, "ext-program": {"minLength": 1, "maxLength": 31, "type": "string", "description": "Specify external application (Program name)", "format": "string-rlx"}}}, "dns": {"type": "object", "properties": {"dns-domain-type": {"enum": ["A", "CNAME", "SOA", "PTR", "MX", "TXT", "AAAA"], "type": "string", "description": "'A': Used for storing Ipv4 address (default); 'CNAME': Canonical name for a DNS alias; 'SOA': Start of authority; 'PTR': Domain name pointer; 'MX': Mail exchanger; 'TXT': Text string; 'AAAA': Used for storing Ipv6 128-bits address; ", "format": "enum"}, "dns-domain": {"description": "Specify fully qualified domain name of the host", "format": "string", "minLength": 1, "maxLength": 255, "not": "dns-ip-key", "type": "string"}, "dns-domain-recurse": {"default": "enabled", "enum": ["enabled", "disabled"], "type": "string", "description": "'enabled': Set the recursion bit; 'disabled': Clear the recursion bit; ", "format": "enum"}, "dns-ipv4-recurse": {"default": "enabled", "enum": ["enabled", "disabled"], "type": "string", "description": "'enabled': Set the recursion bit; 'disabled': Clear the recursion bit; ", "format": "enum"}, "dns-ipv6-port": {"description": "Specify DNS port, default is 53 (DNS Port(default 53))", "format": "number", "default": 53, "maximum": 65534, "minimum": 1, "type": "number"}, "dns-domain-expect": {"type": "object", "properties": {"dns-domain-response": {"minLength": 1, "maxLength": 31, "type": "string", "description": "Specify response code range (e.g. 0,1-5) (Format is xx,xx-xx (xx between [0,15]))", "format": "string-rlx"}}}, "dns-ipv4-port": {"description": "Specify DNS port, default is 53 (DNS Port(default 53))", "format": "number", "default": 53, "maximum": 65534, "minimum": 1, "type": "number"}, "dns-ipv6-expect": {"type": "object", "properties": {"dns-ipv6-response": {"minLength": 1, "maxLength": 31, "type": "string", "description": "Specify response code range (e.g. 0,1-5) (Format is xx,xx-xx (xx between [0,15]))", "format": "string-rlx"}}}, "dns-domain-port": {"description": "Specify DNS port, default is 53 (DNS Port(default 53))", "format": "number", "default": 53, "maximum": 65534, "minimum": 1, "type": "number"}, "dns-ipv6-recurse": {"default": "enabled", "enum": ["enabled", "disabled"], "type": "string", "description": "'enabled': Set the recursion bit; 'disabled': Clear the recursion bit; ", "format": "enum"}, "dns-ipv6-tcp": {"default": 0, "type": "number", "description": "Configure DNS transport over TCP, default is UDP", "format": "flag"}, "dns-ipv4-expect": {"type": "object", "properties": {"dns-ipv4-response": {"minLength": 1, "maxLength": 31, "type": "string", "description": "Specify response code range (e.g. 0,1-5) (Format is xx,xx-xx (xx between [0,15]))", "format": "string-rlx"}}}, "dns-domain-tcp": {"default": 0, "type": "number", "description": "Configure DNS transport over TCP, default is UDP", "format": "flag"}, "dns": {"default": 0, "type": "number", "description": "DNS type", "format": "flag"}, "dns-ipv4-tcp": {"default": 0, "type": "number", "description": "Configure DNS transport over TCP, default is UDP", "format": "flag"}, "dns-ipv4-addr": {"not": "dns-ipv6-addr", "type": "string", "description": "Specify IPv4 address", "format": "ipv4-address"}, "dns-ipv6-addr": {"not": "dns-ipv4-addr", "type": "string", "description": "Specify IPv6 address", "format": "ipv6-address"}, "dns-ip-key": {"default": 0, "not": "dns-domain", "type": "number", "description": "Reverse DNS lookup (Specify IPv4 or IPv6 address)", "format": "flag"}}}, "ldap": {"type": "object", "properties": {"ldap-port": {"description": "Specify the LDAP port (Speciry port number, default is 389, or 636 if LDAP over SSL)", "format": "number", "default": 389, "maximum": 65534, "minimum": 1, "type": "number"}, "ldap-password-string": {"minLength": 1, "maxLength": 31, "type": "string", "description": "Configure password, '' means empty passworddd", "format": "password"}, "ldap-encrypted": {"type": "encrypted", "description": "Do NOT use this option manually. (This is an A10 reserved keyword.) (The ENCRYPTED password string)", "format": "encrypted"}, "BaseDN": {"minLength": 1, "maxLength": 127, "type": "string", "description": "Specify LDAP DN distinguished name", "format": "string-rlx"}, "ldap-query": {"minLength": 1, "maxLength": 255, "type": "string", "description": "LDAP query to be excuted", "format": "string-rlx"}, "ldap-binddn": {"minLength": 1, "maxLength": 127, "type": "string", "description": "Specify the distinguished name for bindRequest (LDAP DN distinguished name)", "format": "string-rlx"}, "ldap-password": {"default": 0, "type": "number", "description": "Specify the user password", "format": "flag"}, "ldap-security": {"enum": ["overssl", "StartTLS"], "type": "string", "description": "'overssl': Set LDAP over SSL; 'StartTLS': LDAP switch to TLS; ", "format": "enum"}, "ldap": {"default": 0, "type": "number", "description": "LDAP type", "format": "flag"}, "AcceptNotFound": {"default": 0, "type": "number", "description": "Mark server up on receiving a not-found response", "format": "flag"}, "ldap-run-search": {"default": 0, "type": "number", "description": "Specify a query to be executed", "format": "flag"}}}, "icmp": {"type": "object", "properties": {"ip": {"not": "ipv6", "type": "string", "description": "Specify IPv4 address of destination behind monitored node", "format": "ipv4-address"}, "icmp": {"default": 0, "type": "number", "description": "ICMP type", "format": "flag"}, "transparent": {"default": 0, "type": "number", "description": "Apply transparent mode", "format": "flag"}, "ipv6": {"not": "ip", "type": "string", "description": "Specify IPv6 address of destination behind monitored node", "format": "ipv6-address"}}}, "kerberos-kdc": {"type": "object", "properties": {"kerberos-cfg": {"type": "object", "properties": {"tcp-only": {"default": 0, "type": "number", "description": "Specify the kerberos tcp only", "format": "flag"}, "kpasswd-pricipal-name": {"minLength": 1, "maxLength": 127, "type": "string", "description": "Specify the pricipal name", "format": "string-rlx"}, "kinit-password": {"minLength": 1, "maxLength": 31, "type": "string", "description": "Password", "format": "password"}, "kpasswd-password": {"minLength": 1, "maxLength": 31, "type": "string", "description": "Password", "format": "password"}, "kpasswd": {"default": 0, "not-list": ["kinit", "kadmin"], "type": "number", "description": "Kerberos change passwd", "format": "flag"}, "kinit-pricipal-name": {"minLength": 1, "maxLength": 127, "type": "string", "description": "Specify the pricipal name", "format": "string-rlx"}, "kpasswd-kdc": {"minLength": 1, "maxLength": 63, "type": "string", "description": "Specify the kdc server, host|ip [:port]", "format": "string-rlx"}, "kpasswd-server": {"minLength": 1, "maxLength": 63, "type": "string", "description": "Specify the Kerberos password server, host|ip [:port]", "format": "string-rlx"}, "kadmin-encrypted": {"type": "encrypted", "description": "Do NOT use this option manually. (This is an A10 reserved keyword.) (The ENCRYPTED password string)", "format": "encrypted"}, "kinit": {"default": 0, "not-list": ["kadmin", "kpasswd"], "type": "number", "description": "Kerberos KDC", "format": "flag"}, "kadmin-pricipal-name": {"minLength": 1, "maxLength": 127, "type": "string", "description": "Specify the pricipal name", "format": "string-rlx"}, "kadmin-realm": {"minLength": 1, "maxLength": 63, "type": "string", "description": "Specify the realm", "format": "string-rlx"}, "kinit-kdc": {"minLength": 1, "maxLength": 63, "type": "string", "description": "Specify the kdc server, host|ip [:port]", "format": "string-rlx"}, "kinit-encrypted": {"type": "encrypted", "description": "Do NOT use this option manually. (This is an A10 reserved keyword.) (The ENCRYPTED password string)", "format": "encrypted"}, "kadmin": {"default": 0, "not-list": ["kinit", "kpasswd"], "type": "number", "description": "Kerberos admin", "format": "flag"}, "kadmin-kdc": {"minLength": 1, "maxLength": 63, "type": "string", "description": "Specify the kdc server, host|ip [:port]", "format": "string-rlx"}, "kadmin-server": {"minLength": 1, "maxLength": 63, "type": "string", "description": "Specify the admin server, host|ip [:port]", "format": "string-rlx"}, "kpasswd-encrypted": {"type": "encrypted", "description": "Do NOT use this option manually. (This is an A10 reserved keyword.) (The ENCRYPTED password string)", "format": "encrypted"}, "kadmin-password": {"minLength": 1, "maxLength": 31, "type": "string", "description": "Password", "format": "password"}}}}}, "imap": {"type": "object", "properties": {"imap-cram-md5": {"default": 0, "type": "number", "description": "Challenge-response authentication mechanism", "format": "flag"}, "imap-port": {"description": "Specify the IMAP port, default is 143 (Port Number (default 143))", "format": "number", "default": 143, "maximum": 65534, "minimum": 1, "type": "number"}, "imap-login": {"default": 0, "type": "number", "description": "Simple login", "format": "flag"}, "imap-password": {"default": 0, "type": "number", "description": "Specify the user password", "format": "flag"}, "imap-password-string": {"minLength": 1, "maxLength": 31, "type": "string", "description": "Configure password, '' means empty passworddd", "format": "password"}, "imap-username": {"minLength": 1, "maxLength": 31, "type": "string", "description": "Specify the username", "format": "string-rlx"}, "imap-encrypted": {"type": "encrypted", "description": "Do NOT use this option manually. (This is an A10 reserved keyword.) (The ENCRYPTED password string)", "format": "encrypted"}, "pwd-auth": {"default": 0, "type": "number", "description": "Specify the Authentication method", "format": "flag"}, "imap-plain": {"default": 0, "type": "number", "description": "Plain text", "format": "flag"}, "imap": {"default": 0, "type": "number", "description": "IMAP type", "format": "flag"}}}}}, "status-code": {"optional": true, "enum": ["status-code-2xx", "status-code-non-5xx"], "type": "string", "description": "'status-code-2xx': Enable passive mode with 2xx http status code; 'status-code-non-5xx': Enable passive mode with non-5xx http status code; ", "format": "enum"}}}], "type": "array", "$ref": "/axapi/v3/health/monitor/{name}"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    URL for this object::
    `https://<Hostname|Ip address>//axapi/v3/health`.

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        self.required=[]
        self.b_key = "health"
        self.a10_url="/axapi/v3/health"
        self.DeviceProxy = ""
        self.A10WW_global = {}
        self.monitor_list = []

        for keys, value in kwargs.items():
            setattr(self,keys, value)





from a10sdk.common.A10BaseClass import A10BaseClass


class Pool(A10BaseClass):
    
    """Class Description::
    Configure IP pool name.

    Class pool supports CRUD Operations and inherits from `common/A10BaseClass`.
    This class is the `"PARENT"` class for this module.`

    :param use_if_ip: {"description": "Use Interface IP", "format": "flag", "default": 0, "type": "number", "plat-pos-list": ["soft-ax"], "optional": true}
    :param start_address: {"optional": true, "modify-not-allowed": 1, "type": "string", "description": "Configure start IP address of NAT pool", "format": "ipv4-address"}
    :param vrid: {"description": "Configure VRRP-A vrid (Specify ha VRRP-A vrid)", "format": "number", "optional": true, "maximum": 31, "minimum": 1, "modify-not-allowed": 1, "type": "number"}
    :param netmask: {"optional": true, "modify-not-allowed": 1, "type": "string", "description": "Configure mask for pool", "format": "ipv4-netmask-brief"}
    :param end_address: {"optional": true, "modify-not-allowed": 1, "type": "string", "description": "Configure end IP address of NAT pool", "format": "ipv4-address"}
    :param ip_rr: {"description": "Use IP address round-robin behavior", "format": "flag", "default": 0, "type": "number", "modify-not-allowed": 1, "optional": true}
    :param ethernet: {"optional": true, "plat-pos-list": ["soft-ax"], "type": "number", "description": "Ethernet interface", "format": "interface"}
    :param gateway: {"optional": true, "modify-not-allowed": 1, "type": "string", "description": "Configure gateway IP", "format": "ipv4-address"}
    :param pool_name: {"description": "Specify pool name or pool group", "format": "string-rlx", "minLength": 1, "optional": false, "maxLength": 63, "type": "string"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    URL for this object::
    `https://<Hostname|Ip address>//axapi/v3/ip/nat/pool/{pool_name}`.

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        self.required = [ "pool_name"]

        self.b_key = "pool"
        self.a10_url="/axapi/v3/ip/nat/pool/{pool_name}"
        self.DeviceProxy = ""
        self.use_if_ip = ""
        self.start_address = ""
        self.vrid = ""
        self.netmask = ""
        self.end_address = ""
        self.ip_rr = ""
        self.ethernet = ""
        self.gateway = ""
        self.pool_name = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)





from a10sdk.common.A10BaseClass import A10BaseClass


class PeriodCfg(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param week: {"default": 0, "type": "number", "description": "Most recent week", "format": "flag"}
    :param all: {"default": 0, "type": "number", "description": "all log", "format": "flag"}
    :param period: {"default": 0, "type": "number", "description": "Specify backup period", "format": "flag"}
    :param month: {"default": 0, "type": "number", "description": " Most recent day", "format": "flag"}
    :param date: {"description": "specify number of days", "minimum": 1, "type": "number", "maximum": 31, "format": "number"}
    :param day: {"default": 0, "type": "number", "description": "Most recent day", "format": "flag"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "period-cfg"
        self.DeviceProxy = ""
        self.week = ""
        self.A10WW_all = ""
        self.period = ""
        self.month = ""
        self.date = ""
        self.day = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class ExpediteCfg(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param stats_data: {"default": 0, "type": "number", "description": "Backup web statistical data", "format": "flag"}
    :param use_mgmt_port: {"default": 0, "type": "number", "description": "Use management port as source port", "format": "flag"}
    :param expedite: {"default": 0, "type": "number", "description": "Expedite the Backup", "format": "flag"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "expedite-cfg"
        self.DeviceProxy = ""
        self.stats_data = ""
        self.period_cfg = {}
        self.use_mgmt_port = ""
        self.expedite = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class Log(A10BaseClass):
    
    """    :param store_name: {"description": "Save backup store information", "format": "string", "minLength": 1, "optional": true, "maxLength": 128, "type": "string"}
    :param remote_file: {"optional": true, "type": "string", "description": "profile name for remote url", "format": "url"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

Class Description::
    Backup log files.

    Class log supports CRUD Operations and inherits from `common/A10BaseClass`.
    This class is the `"PARENT"` class for this module.`

    

    URL for this object::
    `https://<Hostname|Ip address>//axapi/v3/backup/log`.

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        self.required=[]
        self.b_key = "log"
        self.a10_url="/axapi/v3/backup/log"
        self.DeviceProxy = ""
        self.store_name = ""
        self.remote_file = ""
        self.expedite_cfg = {}

        for keys, value in kwargs.items():
            setattr(self,keys, value)





from a10sdk.common.A10BaseClass import A10BaseClass


class GslbIpListAddrList(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param ip: {"type": "string", "description": "Specify IP address", "format": "ipv4-address"}
    :param ip_mask: {"type": "string", "description": "IP mask", "format": "ipv4-netmask"}
    :param id: {"description": "ID Number", "minimum": 0, "type": "number", "maximum": 31, "format": "number"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "gslb-ip-list-addr-list"
        self.DeviceProxy = ""
        self.ip = ""
        self.ip_mask = ""
        self.A10WW_id = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class IpList(A10BaseClass):
    
    """Class Description::
    Specify a IP List.

    Class ip-list supports CRUD Operations and inherits from `common/A10BaseClass`.
    This class is the `"PARENT"` class for this module.`

    :param gslb_ip_list_addr_list: {"minItems": 1, "items": {"type": "object"}, "uniqueItems": true, "type": "array", "array": [{"properties": {"ip": {"type": "string", "description": "Specify IP address", "format": "ipv4-address"}, "ip-mask": {"type": "string", "description": "IP mask", "format": "ipv4-netmask"}, "optional": true, "id": {"description": "ID Number", "minimum": 0, "type": "number", "maximum": 31, "format": "number"}}}]}
    :param gslb_ip_list_filename: {"description": "Load IP List file (IP List filename)", "format": "string-rlx", "minLength": 1, "optional": true, "maxLength": 63, "type": "string"}
    :param gslb_ip_list_obj_name: {"description": "Specify IP List name", "format": "string", "minLength": 1, "optional": false, "maxLength": 63, "type": "string"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    URL for this object::
    `https://<Hostname|Ip address>//axapi/v3/gslb/ip-list/{gslb_ip_list_obj_name}`.

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        self.required = [ "gslb_ip_list_obj_name"]

        self.b_key = "ip-list"
        self.a10_url="/axapi/v3/gslb/ip-list/{gslb_ip_list_obj_name}"
        self.DeviceProxy = ""
        self.gslb_ip_list_addr_list = []
        self.gslb_ip_list_filename = ""
        self.gslb_ip_list_obj_name = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)





from a10sdk.common.A10BaseClass import A10BaseClass


class TypeCfg(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param console_type: {"enum": ["ldap", "local", "radius", "tacplus"], "type": "string", "format": "enum-list"}
    :param type: {"default": 0, "type": "number", "description": "The login authentication type", "format": "flag"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "type-cfg"
        self.DeviceProxy = ""
        self.console_type = ""
        self.A10WW_type = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class Console(A10BaseClass):
    
    """Class Description::
    Configure console authentication type.

    Class console supports CRUD Operations and inherits from `common/A10BaseClass`.
    This class is the `"PARENT"` class for this module.`

    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    URL for this object::
    `https://<Hostname|Ip address>//axapi/v3/authentication/console`.

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        self.required=[]
        self.b_key = "console"
        self.a10_url="/axapi/v3/authentication/console"
        self.DeviceProxy = ""
        self.type_cfg = {}

        for keys, value in kwargs.items():
            setattr(self,keys, value)





from a10sdk.common.A10BaseClass import A10BaseClass


class Arp(A10BaseClass):
    
    """Class Description::
    Configure ARP.

    Class arp supports CRUD Operations and inherits from `common/A10BaseClass`.
    This class is the `"PARENT"` class for this module.`

    :param static_list: {"minItems": 1, "items": {"type": "static"}, "uniqueItems": true, "array": [{"required": ["ip-addr"], "properties": {"ethernet": {"not": "trunk", "optional": true, "type": "number", "description": "Ethernet port. help-val Port Value", "format": "interface"}, "ip-addr": {"optional": false, "type": "string", "description": "IP address", "format": "ipv4-address"}, "mac-addr": {"optional": true, "type": "string", "description": "MAC address", "format": "mac-address"}, "vlan": {"description": "VLAN ID. help-val VLAN Id", "format": "number", "type": "number", "maximum": 4094, "minimum": 1, "optional": true}, "trunk": {"description": "Trunk group. help-val Trunk group", "format": "number", "optional": true, "maximum": 16, "minimum": 1, "not": "ethernet", "type": "number"}}}], "type": "array", "$ref": "https://axapi.a10networks.com/axapi/v3/arp/static/{ip-addr}"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    URL for this object::
    `https://<Hostname|Ip address>//axapi/v3/arp`.

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        self.required=[]
        self.b_key = "arp"
        self.a10_url="/axapi/v3/arp"
        self.DeviceProxy = ""
        self.static_list = []

        for keys, value in kwargs.items():
            setattr(self,keys, value)





from a10sdk.common.A10BaseClass import A10BaseClass


class SystemMemory(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param Max: {"type": "number", "format": "number"}
    :param Allocated: {"type": "number", "format": "number"}
    :param Object_size: {"type": "number", "format": "number"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "System-memory"
        self.DeviceProxy = ""
        self.Max = ""
        self.Allocated = ""
        self.Object_size = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class N2Memory(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param Max: {"type": "number", "format": "number"}
    :param Allocated: {"type": "number", "format": "number"}
    :param Object_size: {"type": "number", "format": "number"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "N2-memory"
        self.DeviceProxy = ""
        self.Max = ""
        self.Allocated = ""
        self.Object_size = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class TcpMemory(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param Max: {"type": "number", "format": "number"}
    :param Allocated: {"type": "number", "format": "number"}
    :param Object_size: {"type": "number", "format": "number"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "TCP-memory"
        self.DeviceProxy = ""
        self.Max = ""
        self.Allocated = ""
        self.Object_size = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class AflexMemory(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param Max: {"type": "number", "format": "number"}
    :param Allocated: {"type": "number", "format": "number"}
    :param Object_size: {"type": "number", "format": "number"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "aFleX-memory"
        self.DeviceProxy = ""
        self.Max = ""
        self.Allocated = ""
        self.Object_size = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class SslMemory(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param Max: {"type": "number", "format": "number"}
    :param Allocated: {"type": "number", "format": "number"}
    :param Object_size: {"type": "number", "format": "number"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "SSL-memory"
        self.DeviceProxy = ""
        self.Max = ""
        self.Allocated = ""
        self.Object_size = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class Oper(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param System_memory: {"minItems": 1, "items": {"type": "object"}, "uniqueItems": true, "type": "array", "array": [{"properties": {"Max": {"type": "number", "format": "number"}, "Allocated": {"type": "number", "format": "number"}, "optional": true, "Object-size": {"type": "number", "format": "number"}}}]}
    :param Used: {"type": "number", "format": "number"}
    :param N2_memory: {"minItems": 1, "items": {"type": "object"}, "uniqueItems": true, "type": "array", "array": [{"properties": {"Max": {"type": "number", "format": "number"}, "Allocated": {"type": "number", "format": "number"}, "optional": true, "Object-size": {"type": "number", "format": "number"}}}]}
    :param TCP_memory: {"minItems": 1, "items": {"type": "object"}, "uniqueItems": true, "type": "array", "array": [{"properties": {"Max": {"type": "number", "format": "number"}, "Allocated": {"type": "number", "format": "number"}, "optional": true, "Object-size": {"type": "number", "format": "number"}}}]}
    :param Free: {"type": "number", "format": "number"}
    :param aFleX_memory: {"minItems": 1, "items": {"type": "object"}, "uniqueItems": true, "type": "array", "array": [{"properties": {"Max": {"type": "number", "format": "number"}, "Allocated": {"type": "number", "format": "number"}, "optional": true, "Object-size": {"type": "number", "format": "number"}}}]}
    :param SSL_memory: {"minItems": 1, "items": {"type": "object"}, "uniqueItems": true, "type": "array", "array": [{"properties": {"Max": {"type": "number", "format": "number"}, "Allocated": {"type": "number", "format": "number"}, "optional": true, "Object-size": {"type": "number", "format": "number"}}}]}
    :param Usage: {"minLength": 1, "maxLength": 63, "type": "string", "format": "string"}
    :param Total: {"type": "number", "format": "number"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "oper"
        self.DeviceProxy = ""
        self.System_memory = []
        self.Used = ""
        self.N2_memory = []
        self.TCP_memory = []
        self.Free = ""
        self.aFleX_memory = []
        self.SSL_memory = []
        self.Usage = ""
        self.Total = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class Memory(A10BaseClass):
    
    """Class Description::
    Operational Status for the object memory.

    Class memory supports CRUD Operations and inherits from `common/A10BaseClass`.
    This class is the `"PARENT"` class for this module.`

    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    URL for this object::
    `https://<Hostname|Ip address>//axapi/v3/system/memory/oper`.

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        self.required=[]
        self.b_key = "memory"
        self.a10_url="/axapi/v3/system/memory/oper"
        self.DeviceProxy = ""
        self.oper = {}

        for keys, value in kwargs.items():
            setattr(self,keys, value)





from a10sdk.common.A10BaseClass import A10BaseClass


class AclCfg(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param ve: {"type": "number", "description": "Virtual ethernet interface. help-val Virtual ethernet interface number", "format": "interface"}
    :param loopback: {"type": "number", "description": "Loopback interface. help-val Port number", "format": "interface"}
    :param metric: {"description": "Metric value", "minimum": 0, "type": "number", "maximum": 16, "format": "number"}
    :param trunk: {"type": "number", "description": "Trunk interface. help-val Trunk interface number", "format": "interface"}
    :param acl: {"minLength": 1, "maxLength": 128, "type": "string", "description": "Access-list name", "format": "string"}
    :param offset_list_direction: {"enum": ["in", "out"], "type": "string", "description": "in: \"Filter incoming updates\"; out: \"Filter outgoing updates\"; ", "format": "enum"}
    :param ethernet: {"type": "number", "description": "Ethernet interface. help-val Port number", "format": "interface"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "acl-cfg"
        self.DeviceProxy = ""
        self.ve = ""
        self.loopback = ""
        self.metric = ""
        self.trunk = ""
        self.acl = ""
        self.offset_list_direction = ""
        self.ethernet = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class Acl(A10BaseClass):
    
    """Class Description::
    acl.

    Class acl supports CRUD Operations and inherits from `common/A10BaseClass`.
    This class is the `"PARENT"` class for this module.`

    :param acl_cfg: {"minItems": 1, "items": {"type": "object"}, "uniqueItems": true, "type": "array", "array": [{"properties": {"ve": {"type": "number", "description": "Virtual ethernet interface. help-val Virtual ethernet interface number", "format": "interface"}, "loopback": {"type": "number", "description": "Loopback interface. help-val Port number", "format": "interface"}, "metric": {"description": "Metric value", "minimum": 0, "type": "number", "maximum": 16, "format": "number"}, "trunk": {"type": "number", "description": "Trunk interface. help-val Trunk interface number", "format": "interface"}, "acl": {"minLength": 1, "maxLength": 128, "type": "string", "description": "Access-list name", "format": "string"}, "offset-list-direction": {"enum": ["in", "out"], "type": "string", "description": "in: \"Filter incoming updates\"; out: \"Filter outgoing updates\"; ", "format": "enum"}, "ethernet": {"type": "number", "description": "Ethernet interface. help-val Port number", "format": "interface"}, "optional": true}}]}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    URL for this object::
    `https://<Hostname|Ip address>//axapi/v3/router/rip/offset-list/acl`.

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        self.required=[]
        self.b_key = "acl"
        self.a10_url="/axapi/v3/router/rip/offset-list/acl"
        self.DeviceProxy = ""
        self.acl_cfg = []

        for keys, value in kwargs.items():
            setattr(self,keys, value)





from a10sdk.common.A10BaseClass import A10BaseClass


class Stats(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param new_svrconn: {"description": "Server conn made", "format": "counter", "type": "number", "oid": "24", "optional": true, "size": "8"}
    :param tcpoutrst: {"description": "Out RSTs", "format": "counter", "type": "number", "oid": "26", "optional": true, "size": "8"}
    :param total_proxy: {"description": "Total Proxy Conns", "format": "counter", "type": "number", "oid": "3", "optional": true, "size": "8"}
    :param fwdreqdata_fail: {"description": "Fwd req data fail", "format": "counter", "type": "number", "oid": "19", "optional": true, "size": "8"}
    :param client_rst: {"description": "Client RST", "format": "counter", "type": "number", "oid": "7", "optional": true, "size": "8"}
    :param svrsel_fail: {"description": "Server selection fail", "format": "counter", "type": "number", "oid": "11", "optional": true, "size": "8"}
    :param req_retran: {"description": "Packets retrans", "format": "counter", "type": "number", "oid": "20", "optional": true, "size": "8"}
    :param close_on_ddos: {"description": "Close on DDoS", "format": "counter", "type": "number", "oid": "195", "optional": true, "size": "8"}
    :param req_over_limit: {"description": "Request over limit", "format": "counter", "type": "number", "oid": "31", "optional": true, "size": "8"}
    :param noproxy: {"description": "No proxy error", "format": "counter", "type": "number", "oid": "6", "optional": true, "size": "8"}
    :param svr_prem_close: {"description": "Server premature close", "format": "counter", "type": "number", "oid": "23", "optional": true, "size": "8"}
    :param parsereq_fail: {"description": "Parse req fail", "format": "counter", "type": "number", "oid": "10", "optional": true, "size": "8"}
    :param req: {"description": "HTTP requests", "format": "counter", "type": "number", "oid": "4", "optional": true, "size": "8"}
    :param full_proxy: {"description": "Full proxy tot", "format": "counter", "type": "number", "oid": "27", "optional": true, "size": "8"}
    :param full_proxy_fpga_err: {"description": "Full proxy fpga err", "format": "counter", "type": "number", "oid": "30", "optional": true, "size": "8"}
    :param server_rst: {"description": "Server RST", "format": "counter", "type": "number", "oid": "8", "optional": true, "size": "8"}
    :param notuple: {"description": "No tuple error", "format": "counter", "type": "number", "oid": "9", "optional": true, "size": "8"}
    :param curr_proxy: {"description": "Curr Proxy Conns", "format": "counter", "type": "number", "oid": "2", "optional": true, "size": "8"}
    :param server_resel: {"description": "Server reselection", "format": "counter", "type": "number", "oid": "22", "optional": true, "size": "8"}
    :param req_ofo: {"description": "Packets ofo", "format": "counter", "type": "number", "oid": "21", "optional": true, "size": "8"}
    :param full_proxy_post: {"description": "Full proxy POST", "format": "counter", "type": "number", "oid": "28", "optional": true, "size": "8"}
    :param snat_fail: {"description": "Source NAT failure", "format": "counter", "type": "number", "oid": "25", "optional": true, "size": "8"}
    :param req_rate_over_limit: {"description": "Request rate over limit", "format": "counter", "type": "number", "oid": "32", "optional": true, "size": "8"}
    :param full_proxy_pipeline: {"description": "Full proxy pipeline", "format": "counter", "type": "number", "oid": "29", "optional": true, "size": "8"}
    :param fwdreq_fail: {"description": "Fwd req fail", "format": "counter", "type": "number", "oid": "12", "optional": true, "size": "8"}
    :param req_succ: {"description": "HTTP requests(succ)", "format": "counter", "type": "number", "oid": "5", "optional": true, "size": "8"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "stats"
        self.DeviceProxy = ""
        self.new_svrconn = ""
        self.tcpoutrst = ""
        self.total_proxy = ""
        self.fwdreqdata_fail = ""
        self.client_rst = ""
        self.svrsel_fail = ""
        self.req_retran = ""
        self.close_on_ddos = ""
        self.req_over_limit = ""
        self.noproxy = ""
        self.svr_prem_close = ""
        self.parsereq_fail = ""
        self.req = ""
        self.full_proxy = ""
        self.full_proxy_fpga_err = ""
        self.server_rst = ""
        self.notuple = ""
        self.curr_proxy = ""
        self.server_resel = ""
        self.req_ofo = ""
        self.full_proxy_post = ""
        self.snat_fail = ""
        self.req_rate_over_limit = ""
        self.full_proxy_pipeline = ""
        self.fwdreq_fail = ""
        self.req_succ = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class FastHttpProxy(A10BaseClass):
    
    """Class Description::
    Statistics for the object fast-http-proxy.

    Class fast-http-proxy supports CRUD Operations and inherits from `common/A10BaseClass`.
    This class is the `"PARENT"` class for this module.`

    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    URL for this object::
    `https://<Hostname|Ip address>//axapi/v3/slb/fast-http-proxy/stats`.

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        self.required=[]
        self.b_key = "fast-http-proxy"
        self.a10_url="/axapi/v3/slb/fast-http-proxy/stats"
        self.DeviceProxy = ""
        self.stats = {}

        for keys, value in kwargs.items():
            setattr(self,keys, value)





from a10sdk.common.A10BaseClass import A10BaseClass


class Template(A10BaseClass):
    
    """Class Description::
    WAF template.

    Class template supports CRUD Operations and inherits from `common/A10BaseClass`.
    This class is the `"PARENT"` class for this module.`

    :param log_succ_reqs: {"default": 0, "optional": true, "type": "number", "description": "Log successful waf requests", "format": "flag"}
    :param keep_end: {"description": "Number of unmasked characters at the end (default: 0)", "format": "number", "type": "number", "maximum": 65535, "minimum": 0, "optional": true}
    :param max_cookie_len: {"description": "Max Cookie length allowed in request (default 4096) (Maximum length of cookie allowed (default 4096))", "format": "number", "default": 4096, "optional": true, "maximum": 65535, "minimum": 0, "type": "number"}
    :param deploy_mode: {"description": "'active': Deploy WAF in active (blocking) mode; 'passive': Deploy WAF in passive (log-only) mode; 'learning': Deploy WAF in learning mode; ", "format": "enum", "default": "active", "type": "string", "enum": ["active", "passive", "learning"], "optional": true}
    :param xml_format_check: {"default": 0, "optional": true, "type": "number", "description": "Check HTTP body for XML format compliance", "format": "flag"}
    :param max_string: {"description": "Maximum length of a string in a JSON request body (default 64) (Maximum length of a JSON string (default 64))", "format": "number", "default": 64, "optional": true, "maximum": 4096, "minimum": 0, "type": "number"}
    :param ccn_mask: {"default": 0, "optional": true, "type": "number", "description": "Mask credit card numbers in response", "format": "flag"}
    :param waf_blist_file: {"description": "Name of WAF policy list file", "format": "string", "minLength": 1, "optional": true, "maxLength": 128, "type": "string"}
    :param form_set_no_cache: {"default": 0, "optional": true, "type": "number", "description": "Disable caching of form-containing responses", "format": "flag"}
    :param http_redirect: {"description": "Send HTTP redirect response (302 Found) to specifed URL (URL to redirect to when denying request)", "format": "string-rlx", "minLength": 1, "not-list": ["http-resp-200", "reset-conn", "http-resp-403"], "optional": true, "maxLength": 255, "type": "string"}
    :param bot_check: {"default": 0, "optional": true, "type": "number", "description": "Check User-Agent for known bots", "format": "flag"}
    :param max_cookies_len: {"description": "Max Total Cookies length allowed in request (default 4096) (Maximum total length of cookies allowed (default 4096))", "format": "number", "default": 4096, "optional": true, "maximum": 65535, "minimum": 0, "type": "number"}
    :param url_check: {"default": 0, "optional": true, "type": "number", "description": "Check URL against list of previously learned URLs", "format": "flag"}
    :param max_parameter_value_len: {"description": "Max HTML parameter value length in an HTTP request (default 4096) (Maximum HTML parameter value in an HTTP request (default 4096))", "format": "number", "default": 4096, "optional": true, "maximum": 102400000, "minimum": 0, "type": "number"}
    :param max_entities: {"description": "Maximum number of MIME entities allowed in request (default 10)", "format": "number", "default": 10, "optional": true, "maximum": 63, "minimum": 0, "type": "number"}
    :param hide_resp_codes: {"default": 0, "optional": true, "type": "number", "description": "Hides response codes that are not allowed (default 4xx, 5xx)", "format": "flag"}
    :param max_depth: {"description": "Maximum recursion depth in a value in a JSON requesnt body (default 16) (Maximum recursion depth in a JSON value (default 16))", "format": "number", "default": 16, "optional": true, "maximum": 4096, "minimum": 0, "type": "number"}
    :param hide_resp_codes_file: {"description": "Name of WAF policy list file", "format": "string", "minLength": 1, "optional": true, "maxLength": 128, "type": "string"}
    :param max_elem_name_len: {"description": "Maximum length for an element name (default 128)", "format": "number", "default": 128, "optional": true, "maximum": 65535, "minimum": 0, "type": "number"}
    :param deny_password_autocomplete: {"default": 0, "optional": true, "type": "number", "description": "Check to protect against server-generated form which contain password fields that allow autocomplete", "format": "flag"}
    :param name: {"description": "WAF Template Name", "format": "string", "minLength": 1, "optional": false, "maxLength": 63, "type": "string"}
    :param http_resp_200: {"description": "Send HTTP response with status code 200 OK", "format": "flag", "default": 0, "optional": true, "not-list": ["http-redirect", "reset-conn", "http-resp-403"], "type": "number"}
    :param keep_start: {"description": "Number of unmasked characters at the beginning (default: 0)", "format": "number", "type": "number", "maximum": 65535, "minimum": 0, "optional": true}
    :param redirect_wlist: {"default": 0, "optional": true, "type": "number", "description": "Check Redirect URL against list of previously learned redirects", "format": "flag"}
    :param max_cookie_value_len: {"description": "Max Cookie Value length allowed in request (default 4096) (Maximum length of cookie value allowed (default 4096))", "format": "number", "default": 4096, "optional": true, "maximum": 65535, "minimum": 0, "type": "number"}
    :param max_cdata_len: {"description": "Maximum length of an CDATA section of an element (default 65535)", "format": "number", "default": 65535, "optional": true, "maximum": 65535, "minimum": 0, "type": "number"}
    :param max_hdr_value_len: {"description": "Max header value length allowed in request (default 4096) (Maximum length of header value allowed (default 4096))", "format": "number", "default": 4096, "optional": true, "maximum": 65535, "minimum": 0, "type": "number"}
    :param secret_encrypted: {"description": "Do NOT use this option manually. (This is an A10 reserved keyword.) (The ENCRYPTED secret string)", "format": "encrypted", "minLength": 1, "optional": true, "maxLength": 255, "type": "encrypted"}
    :param cookie_name: {"description": "Cookie name (simple string or PCRE pattern)", "format": "string-rlx", "minLength": 1, "optional": true, "maxLength": 63, "type": "string"}
    :param max_namespace_uri_len: {"description": "Maximum length of a namespace URI (default 256)", "format": "number", "default": 256, "optional": true, "maximum": 1024, "minimum": 0, "type": "number"}
    :param resp_url_403: {"description": "Response content to send client when denying request", "format": "string-rlx", "minLength": 1, "optional": true, "maxLength": 255, "type": "string"}
    :param csrf_check: {"default": 0, "optional": true, "type": "number", "description": "Tag the form to protect against Cross-site Request Forgery", "format": "flag"}
    :param referer_domain_list: {"description": "List of referer domains allowed", "format": "string-rlx", "minLength": 1, "optional": true, "maxLength": 255, "not": "referer-domain-list-only", "type": "string"}
    :param max_parameters: {"description": "Maximum number of HTML parameters allowed in request (default 64)", "format": "number", "default": 64, "optional": true, "maximum": 1024, "minimum": 0, "type": "number"}
    :param max_parameter_name_len: {"description": "Max HTML parameter name length in an HTTP request (default 256) (Maximum HTML parameter name length in an HTTP request (default 256))", "format": "number", "default": 256, "optional": true, "maximum": 1024, "minimum": 0, "type": "number"}
    :param deny_non_masked_passwords: {"default": 0, "optional": true, "type": "number", "description": "Denies forms that have a password field with a textual type, resulting in this field not being masked", "format": "flag"}
    :param max_hdr_name_len: {"description": "Max header name length allowed in request (default 63) (Maximum length of header name allowed (default 63))", "format": "number", "default": 63, "optional": true, "maximum": 63, "minimum": 0, "type": "number"}
    :param max_elem_depth: {"description": "Maximum recursion level for element definition (default 256)", "format": "number", "default": 256, "optional": true, "maximum": 4096, "minimum": 0, "type": "number"}
    :param form_consistency_check: {"default": 0, "optional": true, "type": "number", "description": "Form input consistency check", "format": "flag"}
    :param max_hdrs: {"description": "Maximum number of headers allowed in request (default 20)", "format": "number", "default": 20, "optional": true, "maximum": 255, "minimum": 0, "type": "number"}
    :param xml_xss_check: {"default": 0, "optional": true, "type": "number", "description": "Check XML data against XSS policy", "format": "flag"}
    :param referer_check: {"default": 0, "optional": true, "type": "number", "description": "Check referer to protect against CSRF attacks", "format": "flag"}
    :param wsdl_resp_val_file: {"description": "Specify name of WSDL file for verifying XML body contents", "format": "string", "minLength": 1, "optional": true, "maxLength": 63, "not": "wsdl-file", "type": "string"}
    :param logging: {"description": "Logging template (Logging Config name)", "format": "string", "minLength": 1, "optional": true, "maxLength": 128, "type": "string", "$ref": "/axapi/v3/slb/template/logging"}
    :param max_namespace: {"description": "Maximum number of namespace declarations (default 16)", "format": "number", "default": 16, "optional": true, "maximum": 256, "minimum": 0, "type": "number"}
    :param max_entity_exp: {"description": "Maximum number of entity expansions (default 1024)", "format": "number", "default": 1024, "optional": true, "maximum": 1024, "minimum": 0, "type": "number"}
    :param form_deny_non_post: {"default": 0, "optional": true, "type": "number", "description": "Deny request with forms if the method is not POST", "format": "flag"}
    :param cookie_encryption_secret: {"description": "Cookie encryption secret", "format": "password", "minLength": 1, "optional": true, "maxLength": 128, "type": "string"}
    :param decode_escaped_chars: {"default": 0, "optional": true, "type": "number", "description": "Decode escaped characters such as \\r \\n \\\" \\xXX \\u00YY in internal url", "format": "flag"}
    :param json_format_check: {"default": 0, "optional": true, "type": "number", "description": "Check HTTP body for JSON format compliance", "format": "flag"}
    :param bot_check_policy_file: {"description": "Name of WAF policy list file", "format": "string", "minLength": 1, "optional": true, "maxLength": 128, "type": "string"}
    :param xml_schema_resp_val_file: {"description": "Specify name of XML-Schema file for verifying XML body contents", "format": "string", "minLength": 1, "optional": true, "maxLength": 63, "not": "xml-schema-file", "type": "string"}
    :param allowed_http_methods: {"description": "List of allowed HTTP methods. Default is \"GET POST\". (List of HTTP methods allowed (default \"GET POST\"))", "format": "string-rlx", "default": "GET POST", "minLength": 1, "optional": true, "maxLength": 255, "type": "string"}
    :param remove_selfref: {"default": 0, "optional": true, "type": "number", "description": "Remove self-references such as /./ and /path/../ from internal url", "format": "flag"}
    :param max_elem_child: {"description": "Maximum number of children of an XML element (default 1024)", "format": "number", "default": 1024, "optional": true, "maximum": 4096, "minimum": 0, "type": "number"}
    :param max_entity_exp_depth: {"description": "Maximum nested depth of entity expansion (default 32)", "format": "number", "default": 32, "optional": true, "maximum": 32, "minimum": 0, "type": "number"}
    :param max_array_value_count: {"description": "Maximum number of values in an array in a JSON request body (default 256) (Maximum number of values in a JSON array (default 256))", "format": "number", "default": 256, "optional": true, "maximum": 4096, "minimum": 0, "type": "number"}
    :param max_elem: {"description": "Maximum number of XML elements (default 1024)", "format": "number", "default": 1024, "optional": true, "maximum": 8192, "minimum": 0, "type": "number"}
    :param sqlia_check: {"optional": true, "enum": ["reject", "sanitize"], "type": "string", "description": "'reject': Reject requests with SQLIA patterns; 'sanitize': Remove bad SQL from request; ", "format": "enum"}
    :param max_object_member_count: {"description": "Maximum number of members in an object in a JSON request body (default 256) (Maximum number of members in a JSON object (default 256))", "format": "number", "default": 256, "optional": true, "maximum": 4096, "minimum": 0, "type": "number"}
    :param http_resp_403: {"description": "Send HTTP response with status code 403 Forbidden (default)", "format": "flag", "default": 0, "optional": true, "not-list": ["http-redirect", "http-resp-200", "reset-conn"], "type": "number"}
    :param http_check: {"default": 0, "optional": true, "type": "number", "description": "Check request for HTTP protocol compliance", "format": "flag"}
    :param max_cookie_name_len: {"description": "Max Cookie Name length allowed in request (default 64) ( Maximum length of cookie name allowed (default 64))", "format": "number", "default": 64, "optional": true, "maximum": 65535, "minimum": 0, "type": "number"}
    :param remove_comments: {"default": 0, "optional": true, "type": "number", "description": "Remove comments from internal url", "format": "flag"}
    :param uri_wlist_check: {"default": 0, "optional": true, "type": "number", "description": "specify name of WAF policy list file to whitelist", "format": "flag"}
    :param form_deny_non_ssl: {"default": 0, "optional": true, "type": "number", "description": "Deny request with forms if the protocol is not SSL", "format": "flag"}
    :param xss_check: {"optional": true, "enum": ["reject", "sanitize"], "type": "string", "description": "'reject': Reject requests with bad cookies; 'sanitize': Remove bad cookies from request; ", "format": "enum"}
    :param reset_conn: {"description": "Reset the client connection", "format": "flag", "default": 0, "optional": true, "not-list": ["http-redirect", "http-resp-200", "http-resp-403"], "type": "number"}
    :param referer_safe_url: {"description": " Safe URL to redirect to if referer is missing", "format": "string-rlx", "minLength": 1, "optional": true, "maxLength": 255, "type": "string"}
    :param max_attr_name_len: {"description": "Maximum length of an attribute name (default 128)", "format": "number", "default": 128, "optional": true, "maximum": 2048, "minimum": 0, "type": "number"}
    :param uri_blist_check: {"default": 0, "optional": true, "type": "number", "description": "specify name of WAF policy list file to blacklist", "format": "flag"}
    :param max_url_len: {"description": "Max URL length allowed in request (default 1024) (Maximum length of URL allowed (default 1024))", "format": "number", "default": 1024, "optional": true, "maximum": 16127, "minimum": 0, "type": "number"}
    :param max_hdrs_len: {"description": "Max headers length allowed in request (default 4096) (Maximum length of headers allowed (default 4096))", "format": "number", "default": 4096, "optional": true, "maximum": 65535, "minimum": 0, "type": "number"}
    :param waf_wlist_file: {"description": "Name of WAF policy list file", "format": "string", "minLength": 1, "optional": true, "maxLength": 128, "type": "string"}
    :param remove_spaces: {"default": 0, "optional": true, "type": "number", "description": "Remove spaces from internal url", "format": "flag"}
    :param lifetime: {"description": "Session lifetime in minutes (default 10)", "format": "number", "type": "number", "maximum": 1440, "minimum": 1, "optional": true}
    :param max_attr: {"description": "Maximum number of attributes of an XML element (default 256)", "format": "number", "default": 256, "optional": true, "maximum": 256, "minimum": 0, "type": "number"}
    :param xss_check_policy_file: {"description": "Name of WAF policy list file", "format": "string", "minLength": 1, "optional": true, "maxLength": 128, "type": "string"}
    :param resp_url_200: {"description": "Response content to send client when denying request", "format": "string-rlx", "minLength": 1, "optional": true, "maxLength": 255, "type": "string"}
    :param max_post_size: {"description": "Max content length allowed in POST request (default 20480) (Maximum size allowed content in an HTTP POST request (default 20480))", "format": "number", "default": 20480, "optional": true, "maximum": 2147483647, "minimum": 0, "type": "number"}
    :param decode_hex_chars: {"default": 0, "optional": true, "type": "number", "description": "Decode hex chars such as \\%xx and \\%u00yy in internal url", "format": "flag"}
    :param max_line_len: {"description": "Max Line length allowed in request (default 1024) (Maximum length of Request line allowed (default 1024))", "format": "number", "default": 1024, "optional": true, "maximum": 16127, "minimum": 0, "type": "number"}
    :param max_query_len: {"description": "Max Query length allowed in request (default 1024) (Maximum length of Request query allowed (default 1024))", "format": "number", "default": 1024, "optional": true, "maximum": 16127, "minimum": 0, "type": "number"}
    :param sqlia_check_policy_file: {"description": "Name of WAF policy list file", "format": "string", "minLength": 1, "optional": true, "maxLength": 128, "type": "string"}
    :param deny_non_ssl_passwords: {"default": 0, "optional": true, "type": "number", "description": "Denies any form that has a password field if the form is not sent over an SSL connection", "format": "flag"}
    :param max_data_parse: {"description": "Max data parsed for Web Application Firewall (default 65536) (Maximum data parsed for Web Application Firewall (default 65536))", "format": "number", "default": 65536, "optional": true, "maximum": 1048575, "minimum": 0, "type": "number"}
    :param max_parameter_total_len: {"description": "Max HTML parameter tatal length in an HTTP request (default 4096) (Maximum HTML parameter total length in an HTTP request (default 4096))", "format": "number", "default": 4096, "optional": true, "maximum": 102400000, "minimum": 0, "type": "number"}
    :param wsdl_file: {"description": "Specify name of WSDL file for verifying XML body contents", "format": "string", "minLength": 1, "optional": true, "maxLength": 63, "not": "wsdl-resp-val-file", "type": "string"}
    :param session_check: {"default": 0, "optional": true, "type": "number", "description": "Enable session checking via session cookie", "format": "flag"}
    :param disable: {"default": 0, "optional": true, "type": "number", "description": "Disable buffer overflow protection", "format": "flag"}
    :param filter_resp_hdrs: {"default": 0, "optional": true, "type": "number", "description": "Removes web server's identifying headers", "format": "flag"}
    :param max_cookies: {"description": "Maximum number of cookies allowed in request (default 20)", "format": "number", "default": 20, "optional": true, "maximum": 63, "minimum": 0, "type": "number"}
    :param decode_entities: {"default": 0, "optional": true, "type": "number", "description": "Decode entities in internal url", "format": "flag"}
    :param mask: {"description": "Character to mask the matched pattern (default: X)", "format": "string", "minLength": 1, "optional": true, "maxLength": 1, "type": "string"}
    :param referer_domain_list_only: {"description": "List of referer domains allowed", "format": "string-rlx", "minLength": 1, "optional": true, "maxLength": 255, "not": "referer-domain-list", "type": "string"}
    :param max_attr_value_len: {"description": "Maximum length of an attribute text value (default 128)", "format": "number", "default": 128, "optional": true, "maximum": 4096, "minimum": 0, "type": "number"}
    :param pcre_mask: {"description": "Mask matched PCRE pattern in response", "format": "string-rlx", "minLength": 1, "optional": true, "maxLength": 63, "type": "string"}
    :param soap_format_check: {"default": 0, "optional": true, "type": "number", "description": "Check XML document for SOAP format compliance", "format": "flag"}
    :param xml_schema_file: {"description": "Specify name of XML-Schema file for verifying XML body contents", "format": "string", "minLength": 1, "optional": true, "maxLength": 63, "not": "xml-schema-resp-val-file", "type": "string"}
    :param ssn_mask: {"default": 0, "optional": true, "type": "number", "description": "Mask US Social Security numbers in response", "format": "flag"}
    :param xml_sqlia_check: {"default": 0, "optional": true, "type": "number", "description": "Check XML data against SQLIA policy", "format": "flag"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    URL for this object::
    `https://<Hostname|Ip address>//axapi/v3/waf/template/{name}`.

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        self.required = [ "name"]

        self.b_key = "template"
        self.a10_url="/axapi/v3/waf/template/{name}"
        self.DeviceProxy = ""
        self.log_succ_reqs = ""
        self.keep_end = ""
        self.max_cookie_len = ""
        self.deploy_mode = ""
        self.xml_format_check = ""
        self.max_string = ""
        self.ccn_mask = ""
        self.waf_blist_file = ""
        self.form_set_no_cache = ""
        self.http_redirect = ""
        self.bot_check = ""
        self.max_cookies_len = ""
        self.url_check = ""
        self.max_parameter_value_len = ""
        self.max_entities = ""
        self.hide_resp_codes = ""
        self.max_depth = ""
        self.hide_resp_codes_file = ""
        self.max_elem_name_len = ""
        self.deny_password_autocomplete = ""
        self.name = ""
        self.http_resp_200 = ""
        self.keep_start = ""
        self.redirect_wlist = ""
        self.max_cookie_value_len = ""
        self.max_cdata_len = ""
        self.max_hdr_value_len = ""
        self.secret_encrypted = ""
        self.cookie_name = ""
        self.max_namespace_uri_len = ""
        self.resp_url_403 = ""
        self.csrf_check = ""
        self.referer_domain_list = ""
        self.max_parameters = ""
        self.max_parameter_name_len = ""
        self.deny_non_masked_passwords = ""
        self.max_hdr_name_len = ""
        self.max_elem_depth = ""
        self.form_consistency_check = ""
        self.max_hdrs = ""
        self.xml_xss_check = ""
        self.referer_check = ""
        self.wsdl_resp_val_file = ""
        self.logging = ""
        self.max_namespace = ""
        self.max_entity_exp = ""
        self.form_deny_non_post = ""
        self.cookie_encryption_secret = ""
        self.decode_escaped_chars = ""
        self.json_format_check = ""
        self.bot_check_policy_file = ""
        self.xml_schema_resp_val_file = ""
        self.allowed_http_methods = ""
        self.remove_selfref = ""
        self.max_elem_child = ""
        self.max_entity_exp_depth = ""
        self.max_array_value_count = ""
        self.max_elem = ""
        self.sqlia_check = ""
        self.max_object_member_count = ""
        self.http_resp_403 = ""
        self.http_check = ""
        self.max_cookie_name_len = ""
        self.remove_comments = ""
        self.uri_wlist_check = ""
        self.form_deny_non_ssl = ""
        self.xss_check = ""
        self.reset_conn = ""
        self.referer_safe_url = ""
        self.max_attr_name_len = ""
        self.uri_blist_check = ""
        self.max_url_len = ""
        self.max_hdrs_len = ""
        self.waf_wlist_file = ""
        self.remove_spaces = ""
        self.lifetime = ""
        self.max_attr = ""
        self.xss_check_policy_file = ""
        self.resp_url_200 = ""
        self.max_post_size = ""
        self.decode_hex_chars = ""
        self.max_line_len = ""
        self.max_query_len = ""
        self.sqlia_check_policy_file = ""
        self.deny_non_ssl_passwords = ""
        self.max_data_parse = ""
        self.max_parameter_total_len = ""
        self.wsdl_file = ""
        self.session_check = ""
        self.disable = ""
        self.filter_resp_hdrs = ""
        self.max_cookies = ""
        self.decode_entities = ""
        self.mask = ""
        self.referer_domain_list_only = ""
        self.max_attr_value_len = ""
        self.pcre_mask = ""
        self.soap_format_check = ""
        self.xml_schema_file = ""
        self.ssn_mask = ""
        self.xml_sqlia_check = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)





from a10sdk.common.A10BaseClass import A10BaseClass


class IpMultipleFields(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param ip_addr2_sub: {"type": "string", "description": "Specify IP address range", "format": "ipv4-address"}
    :param ip_sub: {"type": "string", "description": "Specify IP information", "format": "ipv4-address"}
    :param ip_mask_sub: {"type": "string", "description": "Specify IP/mask format (Specify IP address mask)", "format": "ipv4-netmask-brief"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "ip-multiple-fields"
        self.DeviceProxy = ""
        self.ip_addr2_sub = ""
        self.ip_sub = ""
        self.ip_mask_sub = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class Ipv6MultipleFields(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param ipv6_mask_sub: {"description": "Specify IPv6/mask format (Specify IP address mask)", "minimum": 0, "type": "number", "maximum": 128, "format": "number"}
    :param ipv6_sub: {"type": "string", "description": "Specify IPv6 information", "format": "ipv6-address"}
    :param ipv6_addr2_sub: {"type": "string", "description": "Specify IPv6 address range", "format": "ipv6-address"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "ipv6-multiple-fields"
        self.DeviceProxy = ""
        self.ipv6_mask_sub = ""
        self.ipv6_sub = ""
        self.ipv6_addr2_sub = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class GeoLocation(A10BaseClass):
    
    """Class Description::
    Specify geo-location.

    Class geo-location supports CRUD Operations and inherits from `common/A10BaseClass`.
    This class is the `"PARENT"` class for this module.`

    :param ip_multiple_fields: {"minItems": 1, "items": {"type": "object"}, "uniqueItems": true, "type": "array", "array": [{"properties": {"ip-addr2-sub": {"type": "string", "description": "Specify IP address range", "format": "ipv4-address"}, "optional": true, "ip-sub": {"type": "string", "description": "Specify IP information", "format": "ipv4-address"}, "ip-mask-sub": {"type": "string", "description": "Specify IP/mask format (Specify IP address mask)", "format": "ipv4-netmask-brief"}}}]}
    :param name: {"description": "Specify geo-location name, section range is (1-15)", "format": "string", "minLength": 1, "optional": false, "maxLength": 127, "type": "string"}
    :param ipv6_multiple_fields: {"minItems": 1, "items": {"type": "object"}, "uniqueItems": true, "type": "array", "array": [{"properties": {"ipv6-mask-sub": {"description": "Specify IPv6/mask format (Specify IP address mask)", "minimum": 0, "type": "number", "maximum": 128, "format": "number"}, "ipv6-sub": {"type": "string", "description": "Specify IPv6 information", "format": "ipv6-address"}, "optional": true, "ipv6-addr2-sub": {"type": "string", "description": "Specify IPv6 address range", "format": "ipv6-address"}}}]}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    URL for this object::
    `https://<Hostname|Ip address>//axapi/v3/gslb/policy/{name}/geo-location/{name}`.

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        self.required = [ "name"]

        self.b_key = "geo-location"
        self.a10_url="/axapi/v3/gslb/policy/{name}/geo-location/{name}"
        self.DeviceProxy = ""
        self.ip_multiple_fields = []
        self.name = ""
        self.ipv6_multiple_fields = []

        for keys, value in kwargs.items():
            setattr(self,keys, value)





from a10sdk.common.A10BaseClass import A10BaseClass


class Oper(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param fan3a_report: {"minLength": 1, "maxLength": 63, "type": "string", "format": "string"}
    :param power_unit1: {"minLength": 1, "maxLength": 63, "type": "string", "format": "string"}
    :param power_unit3: {"minLength": 1, "maxLength": 63, "type": "string", "format": "string"}
    :param power_unit2: {"minLength": 1, "maxLength": 63, "type": "string", "format": "string"}
    :param fan8a_report: {"minLength": 1, "maxLength": 63, "type": "string", "format": "string"}
    :param voltage_label_17: {"minLength": 1, "maxLength": 63, "type": "string", "format": "string"}
    :param voltage_label_16: {"minLength": 1, "maxLength": 63, "type": "string", "format": "string"}
    :param voltage_label_15: {"minLength": 1, "maxLength": 63, "type": "string", "format": "string"}
    :param voltage_label_14: {"minLength": 1, "maxLength": 63, "type": "string", "format": "string"}
    :param voltage_label_13: {"minLength": 1, "maxLength": 63, "type": "string", "format": "string"}
    :param voltage_label_12: {"minLength": 1, "maxLength": 63, "type": "string", "format": "string"}
    :param voltage_label_11: {"minLength": 1, "maxLength": 63, "type": "string", "format": "string"}
    :param voltage_label_10: {"minLength": 1, "maxLength": 63, "type": "string", "format": "string"}
    :param fan6b_report: {"minLength": 1, "maxLength": 63, "type": "string", "format": "string"}
    :param voltage_label_3: {"minLength": 1, "maxLength": 63, "type": "string", "format": "string"}
    :param physical_temperature: {"minLength": 1, "maxLength": 63, "type": "string", "format": "string"}
    :param fan5a_report: {"minLength": 1, "maxLength": 63, "type": "string", "format": "string"}
    :param fan8b_report: {"minLength": 1, "maxLength": 63, "type": "string", "format": "string"}
    :param fan2a_report: {"minLength": 1, "maxLength": 63, "type": "string", "format": "string"}
    :param fan5b_report: {"minLength": 1, "maxLength": 63, "type": "string", "format": "string"}
    :param fan10b_report: {"minLength": 1, "maxLength": 63, "type": "string", "format": "string"}
    :param fan7b_report: {"minLength": 1, "maxLength": 63, "type": "string", "format": "string"}
    :param voltage_label_4: {"minLength": 1, "maxLength": 63, "type": "string", "format": "string"}
    :param fan9b_report: {"minLength": 1, "maxLength": 63, "type": "string", "format": "string"}
    :param power_unit4: {"minLength": 1, "maxLength": 63, "type": "string", "format": "string"}
    :param fan1b_report: {"minLength": 1, "maxLength": 63, "type": "string", "format": "string"}
    :param voltage_label_9: {"minLength": 1, "maxLength": 63, "type": "string", "format": "string"}
    :param fan10a_report: {"minLength": 1, "maxLength": 63, "type": "string", "format": "string"}
    :param fan2b_report: {"minLength": 1, "maxLength": 63, "type": "string", "format": "string"}
    :param fan4b_report: {"minLength": 1, "maxLength": 63, "type": "string", "format": "string"}
    :param fan9a_report: {"minLength": 1, "maxLength": 63, "type": "string", "format": "string"}
    :param voltage_label_2: {"minLength": 1, "maxLength": 63, "type": "string", "format": "string"}
    :param voltage_label_1: {"minLength": 1, "maxLength": 63, "type": "string", "format": "string"}
    :param voltage_label_7: {"minLength": 1, "maxLength": 63, "type": "string", "format": "string"}
    :param voltage_label_6: {"minLength": 1, "maxLength": 63, "type": "string", "format": "string"}
    :param voltage_label_5: {"minLength": 1, "maxLength": 63, "type": "string", "format": "string"}
    :param fan6a_report: {"minLength": 1, "maxLength": 63, "type": "string", "format": "string"}
    :param fan1a_report: {"minLength": 1, "maxLength": 63, "type": "string", "format": "string"}
    :param fan4a_report: {"minLength": 1, "maxLength": 63, "type": "string", "format": "string"}
    :param fan7a_report: {"minLength": 1, "maxLength": 63, "type": "string", "format": "string"}
    :param voltage_label_8: {"minLength": 1, "maxLength": 63, "type": "string", "format": "string"}
    :param fan3b_report: {"minLength": 1, "maxLength": 63, "type": "string", "format": "string"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "oper"
        self.DeviceProxy = ""
        self.fan3a_report = ""
        self.power_unit1 = ""
        self.power_unit3 = ""
        self.power_unit2 = ""
        self.fan8a_report = ""
        self.voltage_label_17 = ""
        self.voltage_label_16 = ""
        self.voltage_label_15 = ""
        self.voltage_label_14 = ""
        self.voltage_label_13 = ""
        self.voltage_label_12 = ""
        self.voltage_label_11 = ""
        self.voltage_label_10 = ""
        self.fan6b_report = ""
        self.voltage_label_3 = ""
        self.physical_temperature = ""
        self.fan5a_report = ""
        self.fan8b_report = ""
        self.fan2a_report = ""
        self.fan5b_report = ""
        self.fan10b_report = ""
        self.fan7b_report = ""
        self.voltage_label_4 = ""
        self.fan9b_report = ""
        self.power_unit4 = ""
        self.fan1b_report = ""
        self.voltage_label_9 = ""
        self.fan10a_report = ""
        self.fan2b_report = ""
        self.fan4b_report = ""
        self.fan9a_report = ""
        self.voltage_label_2 = ""
        self.voltage_label_1 = ""
        self.voltage_label_7 = ""
        self.voltage_label_6 = ""
        self.voltage_label_5 = ""
        self.fan6a_report = ""
        self.fan1a_report = ""
        self.fan4a_report = ""
        self.fan7a_report = ""
        self.voltage_label_8 = ""
        self.fan3b_report = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class Environment(A10BaseClass):
    
    """Class Description::
    Operational Status for the object environment.

    Class environment supports CRUD Operations and inherits from `common/A10BaseClass`.
    This class is the `"PARENT"` class for this module.`

    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    URL for this object::
    `https://<Hostname|Ip address>//axapi/v3/system/environment/oper`.

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        self.required=[]
        self.b_key = "environment"
        self.a10_url="/axapi/v3/system/environment/oper"
        self.DeviceProxy = ""
        self.oper = {}

        for keys, value in kwargs.items():
            setattr(self,keys, value)





from a10sdk.common.A10BaseClass import A10BaseClass


class Network(A10BaseClass):
    
    """Class Description::
    Specify a network to announce via BGP.

    Class network supports CRUD Operations and inherits from `common/A10BaseClass`.
    This class is the `"PARENT"` class for this module.`

    :param ip_mask_list: {"minItems": 1, "items": {"type": "ip-mask"}, "uniqueItems": true, "array": [{"required": ["network-ipv4", "mask"], "properties": {"description": {"optional": true, "type": "string", "description": "Network specific description (Up to 80 characters describing this network)", "format": "string-rlx"}, "route-map": {"description": "Route-map to modify the attributes (Name of the route map)", "format": "string", "minLength": 1, "optional": true, "maxLength": 128, "type": "string"}, "mask": {"optional": false, "type": "string", "description": "Specify network mask (Network mask, e.g., 255.255.0.0)", "format": "ipv4-netmask"}, "comm-value": {"optional": true, "type": "string", "description": "community value in the format 1-4294967295|AA:NN|internet|local-AS|no-advertise|no-export", "format": "string-rlx"}, "backdoor": {"default": 0, "optional": true, "type": "number", "description": "Specify a BGP backdoor route", "format": "flag"}, "network-ipv4": {"optional": false, "type": "string", "description": "IP prefix", "format": "ipv4-address"}}}], "type": "array", "$ref": "/axapi/v3/router/bgp/{as-number}/network/ip-mask/{network-ipv4}+{mask}"}
    :param ip_cidr_list: {"minItems": 1, "items": {"type": "ip-cidr"}, "uniqueItems": true, "array": [{"required": ["network-ipv4-cidr"], "properties": {"backdoor": {"default": 0, "optional": true, "type": "number", "description": "Specify a BGP backdoor route", "format": "flag"}, "route-map": {"description": "Route-map to modify the attributes (Name of the route map)", "format": "string", "minLength": 1, "optional": true, "maxLength": 128, "type": "string"}, "network-ipv4-cidr": {"optional": false, "type": "string", "description": "Specify network mask", "format": "ipv4-cidr"}, "description": {"optional": true, "type": "string", "description": "Network specific description (Up to 80 characters describing this network)", "format": "string-rlx"}, "comm-value": {"optional": true, "type": "string", "description": "community value in the format 1-4294967295|AA:NN|internet|local-AS|no-advertise|no-export", "format": "string-rlx"}}}], "type": "array", "$ref": "/axapi/v3/router/bgp/{as-number}/network/ip-cidr/{network-ipv4-cidr}"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    URL for this object::
    `https://<Hostname|Ip address>//axapi/v3/router/bgp/{as_number}/network`.

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        self.required=[]
        self.b_key = "network"
        self.a10_url="/axapi/v3/router/bgp/{as_number}/network"
        self.DeviceProxy = ""
        self.synchronization = {}
        self.ip_mask_list = []
        self.ip_cidr_list = []

        for keys, value in kwargs.items():
            setattr(self,keys, value)





from a10sdk.common.A10BaseClass import A10BaseClass


class Exception(A10BaseClass):
    
    """    :param action: {"optional": true, "enum": ["add", "delete", "clean"], "type": "string", "description": "'add': Add an exception; 'delete': Delete an exception; 'clean': Delete all exception; ", "format": "enum"}
    :param certificate_name: {"description": "The certificate name", "format": "string", "minLength": 1, "optional": true, "maxLength": 128, "type": "string"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

Class Description::
    Config the exception which will not be checked.

    Class exception supports CRUD Operations and inherits from `common/A10BaseClass`.
    This class is the `"PARENT"` class for this module.`

    

    URL for this object::
    `https://<Hostname|Ip address>//axapi/v3/slb/ssl-expire-check/exception`.

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        self.required=[]
        self.b_key = "exception"
        self.a10_url="/axapi/v3/slb/ssl-expire-check/exception"
        self.DeviceProxy = ""
        self.action = ""
        self.certificate_name = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)





from a10sdk.common.A10BaseClass import A10BaseClass


class Oper(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param state: {"enum": ["All-Up", "Functional-Up", "Partial-Up", "Down", "Disabled", "Unknown"], "type": "string", "format": "enum"}
    :param servers_down: {"type": "number", "format": "number"}
    :param servers_up: {"type": "number", "format": "number"}
    :param servers_disable: {"type": "number", "format": "number"}
    :param servers_total: {"type": "number", "format": "number"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "oper"
        self.DeviceProxy = ""
        self.state = ""
        self.servers_down = ""
        self.servers_up = ""
        self.servers_disable = ""
        self.servers_total = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class ServiceGroup(A10BaseClass):
    
    """Class Description::
    Operational Status for the object service-group.

    Class service-group supports CRUD Operations and inherits from `common/A10BaseClass`.
    This class is the `"PARENT"` class for this module.`

    :param member_list: {"minItems": 1, "items": {"type": "member"}, "uniqueItems": true, "array": [{"required": ["name", "port"], "properties": {"oper": {"type": "object", "properties": {"state": {"enum": ["UP", "DOWN", "MAINTENANCE"], "type": "string", "format": "enum"}}}, "name": {"description": "Member name", "format": "comp-string", "minLength": 1, "oid": "1001", "optional": false, "maxLength": 127, "type": "string"}, "port": {"description": "Port number", "format": "number", "default": 65534, "optional": false, "oid": "1002", "maximum": 65534, "minimum": 0, "type": "number"}}}], "type": "array", "$ref": "/axapi/v3/slb/service-group/{name}/member/{name}+{port}"}
    :param name: {"description": "SLB Service Name", "format": "string-rlx", "minLength": 1, "oid": "1001", "optional": false, "maxLength": 127, "type": "string"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    URL for this object::
    `https://<Hostname|Ip address>//axapi/v3/slb/service-group/{name}/oper`.

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        self.required=[]
        self.b_key = "service-group"
        self.a10_url="/axapi/v3/slb/service-group/{name}/oper"
        self.DeviceProxy = ""
        self.oper = {}
        self.member_list = []
        self.name = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)





from a10sdk.common.A10BaseClass import A10BaseClass


class LogReceiver(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param encrypted: {"type": "encrypted", "description": "Do NOT use this option manually. (This is an A10 reserved keyword.) (The ENCRYPTED secret string)", "format": "encrypted"}
    :param radius: {"default": 0, "type": "number", "description": "Use RADIUS server for NAT logging", "format": "flag"}
    :param secret_string: {"minLength": 1, "maxLength": 127, "type": "string", "description": "The RADIUS server's secret", "format": "password"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "log-receiver"
        self.DeviceProxy = ""
        self.encrypted = ""
        self.radius = ""
        self.secret_string = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class Severity(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param severity_string: {"description": "'emergency': 0: Emergency; 'alert': 1: Alert; 'critical': 2: Critical; 'error': 3: Error; 'warning': 4: Warning; 'notice': 5: Notice; 'informational': 6: Informational; 'debug': 7: Debug; ", "format": "enum", "default": "debug", "enum": ["emergency", "alert", "critical", "error", "warning", "notice", "informational", "debug"], "not": "severity-val", "type": "string"}
    :param severity_val: {"description": "Logging severity level", "format": "number", "default": 7, "maximum": 7, "minimum": 0, "not": "severity-string", "type": "number"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "severity"
        self.DeviceProxy = ""
        self.severity_string = ""
        self.severity_val = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class AttrCfg(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param attr_event: {"enum": ["http-requests", "port-mappings", "sessions"], "type": "string", "description": "'http-requests': Include in HTTP request logs; 'port-mappings': Include in port-mapping logs; 'sessions': Include in session logs; ", "format": "enum"}
    :param attr: {"enum": ["imei", "imsi", "msisdn", "custom1", "custom2", "custom3"], "type": "string", "description": "'imei': Include IMEI; 'imsi': Include IMSI; 'msisdn': Include MSISDN; 'custom1': Customized attribute 1; 'custom2': Customized attribute 2; 'custom3': Customized attribute 3; ", "format": "enum"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "attr-cfg"
        self.DeviceProxy = ""
        self.attr_event = ""
        self.attr = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class IncludeRadiusAttribute(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param attr_cfg: {"minItems": 1, "items": {"type": "object"}, "uniqueItems": true, "type": "array", "array": [{"properties": {"attr-event": {"enum": ["http-requests", "port-mappings", "sessions"], "type": "string", "description": "'http-requests': Include in HTTP request logs; 'port-mappings': Include in port-mapping logs; 'sessions': Include in session logs; ", "format": "enum"}, "optional": true, "attr": {"enum": ["imei", "imsi", "msisdn", "custom1", "custom2", "custom3"], "type": "string", "description": "'imei': Include IMEI; 'imsi': Include IMSI; 'msisdn': Include MSISDN; 'custom1': Customized attribute 1; 'custom2': Customized attribute 2; 'custom3': Customized attribute 3; ", "format": "enum"}}}]}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "include-radius-attribute"
        self.DeviceProxy = ""
        self.attr_cfg = []

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class DestPort(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param include_byte_count: {"default": 0, "type": "number", "description": "Include the byte count of HTTP Request/Response in CGN session deletion logs", "format": "flag"}
    :param dest_port_number: {"minimum": 1, "type": "number", "maximum": 65535, "format": "number"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "dest-port"
        self.DeviceProxy = ""
        self.include_byte_count = ""
        self.dest_port_number = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class RuleHttpRequests(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param log_every_http_request: {"default": 0, "type": "number", "description": "Log every HTTP request in an HTTP 1.1 session (Default: Log the first HTTP request in a session)", "format": "flag"}
    :param dest_port: {"minItems": 1, "items": {"type": "object"}, "uniqueItems": true, "type": "array", "array": [{"properties": {"include-byte-count": {"default": 0, "type": "number", "description": "Include the byte count of HTTP Request/Response in CGN session deletion logs", "format": "flag"}, "optional": true, "dest-port-number": {"minimum": 1, "type": "number", "maximum": 65535, "format": "number"}}}]}
    :param max_url_len: {"description": "Max length of URL log (Max URL length (Default: 100 char))", "format": "number", "default": 100, "maximum": 1000, "minimum": 100, "type": "number"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "rule-http-requests"
        self.DeviceProxy = ""
        self.log_every_http_request = ""
        self.dest_port = []
        self.max_url_len = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class Rule(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "rule"
        self.DeviceProxy = ""
        self.rule_http_requests = {}

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class CustomMessage(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param custom_http_request_got: {"minLength": 1, "maxLength": 255, "type": "string", "description": "HTTP request got (Custom message string)", "format": "string-rlx"}
    :param custom_fixed_nat_allocated: {"minLength": 1, "maxLength": 255, "type": "string", "description": "Fixed-NAT allocated (Custom message string)", "format": "string-rlx"}
    :param custom_port_batch_freed: {"minLength": 1, "maxLength": 255, "type": "string", "description": "Port Batch freed (Custom message string)", "format": "string-rlx"}
    :param custom_fixed_nat_freed: {"minLength": 1, "maxLength": 255, "type": "string", "description": "Fixed-NAT freed (Custom message string)", "format": "string-rlx"}
    :param custom_port_batch_allocated: {"minLength": 1, "maxLength": 255, "type": "string", "description": "Port Batch allocated (Custom message string)", "format": "string-rlx"}
    :param custom_port_allocated: {"minLength": 1, "maxLength": 255, "type": "string", "description": "Port allocated (Custom message string)", "format": "string-rlx"}
    :param custom_session_deleted: {"minLength": 1, "maxLength": 255, "type": "string", "description": "Session deleted (Custom message string)", "format": "string-rlx"}
    :param custom_port_freed: {"minLength": 1, "maxLength": 255, "type": "string", "description": "Port freed (Custom message string)", "format": "string-rlx"}
    :param custom_session_created: {"minLength": 1, "maxLength": 255, "type": "string", "description": "Session created (Custom message string)", "format": "string-rlx"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "custom-message"
        self.DeviceProxy = ""
        self.custom_http_request_got = ""
        self.custom_fixed_nat_allocated = ""
        self.custom_port_batch_freed = ""
        self.custom_fixed_nat_freed = ""
        self.custom_port_batch_allocated = ""
        self.custom_port_allocated = ""
        self.custom_session_deleted = ""
        self.custom_port_freed = ""
        self.custom_session_created = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class Custom(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param custom_header: {"enum": ["use-syslog-header"], "type": "string", "description": "'use-syslog-header': Use syslog header as custom log header; ", "format": "enum"}
    :param custom_time_stamp_format: {"minLength": 1, "maxLength": 31, "type": "string", "description": "Customize the time stamp format (Customize the time-stamp format. Default:%Y%m%d%H%M%S)", "format": "string-rlx"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "custom"
        self.DeviceProxy = ""
        self.custom_header = ""
        self.custom_message = {}
        self.custom_time_stamp_format = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class Header(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param use_alternate_timestamp: {"default": 0, "type": "number", "description": "Use alternate non-RFC5424 compliant timestamp. Ex: 1990 Jan 15 12:30:30", "format": "flag"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "header"
        self.DeviceProxy = ""
        self.use_alternate_timestamp = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class Ipv6Tech(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param fixed_nat_freed: {"minLength": 1, "maxLength": 255, "type": "string", "description": "Fixed-NAT freed (Custom message string. Should be in the format of \"MSGID [STRUCTURED-DATA] MSG\")", "format": "string-rlx"}
    :param port_batch_freed: {"minLength": 1, "maxLength": 255, "type": "string", "description": "Port Batch freed (Custom message string. Should be in the format of \"MSGID [STRUCTURED-DATA] MSG\")", "format": "string-rlx"}
    :param tech_type: {"enum": ["lsn", "nat64", "ds-lite", "sixrd-nat64"], "type": "string", "description": "'lsn': LSN; 'nat64': NAT64; 'ds-lite': DS-Lite; 'sixrd-nat64': 6rd-NAT64; ", "format": "enum"}
    :param fixed_nat_allocated: {"minLength": 1, "maxLength": 255, "type": "string", "description": "Fixed-NAT allocated (Custom message string. Should be in the format of \"MSGID [STRUCTURED-DATA] MSG\")", "format": "string-rlx"}
    :param port_allocated: {"minLength": 1, "maxLength": 255, "type": "string", "description": "Port allocated (Custom message string. Should be in the format of \"MSGID [STRUCTURED-DATA] MSG\")", "format": "string-rlx"}
    :param port_freed: {"minLength": 1, "maxLength": 255, "type": "string", "description": "Port freed (Custom message string. Should be in the format of \"MSGID [STRUCTURED-DATA] MSG\")", "format": "string-rlx"}
    :param port_batch_allocated: {"minLength": 1, "maxLength": 255, "type": "string", "description": "Port Batch allocated (Custom message string. Should be in the format of \"MSGID [STRUCTURED-DATA] MSG\")", "format": "string-rlx"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "ipv6-tech"
        self.DeviceProxy = ""
        self.fixed_nat_freed = ""
        self.port_batch_freed = ""
        self.tech_type = ""
        self.fixed_nat_allocated = ""
        self.port_allocated = ""
        self.port_freed = ""
        self.port_batch_allocated = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class Message(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param session_created: {"minLength": 1, "maxLength": 255, "type": "string", "description": "Session created (Custom message string. Should be in the format of \"MSGID [STRUCTURED-DATA] MSG\")", "format": "string-rlx"}
    :param http_request_got: {"minLength": 1, "maxLength": 255, "type": "string", "description": "HTTP request got (Custom message string. Should be in the format of \"MSGID [STRUCTURED-DATA] MSG\")", "format": "string-rlx"}
    :param session_deleted: {"minLength": 1, "maxLength": 255, "type": "string", "description": "Session deleted (Custom message string. Should be in the format of \"MSGID [STRUCTURED-DATA] MSG\")", "format": "string-rlx"}
    :param ipv6_tech: {"minItems": 1, "items": {"type": "object"}, "uniqueItems": true, "type": "array", "array": [{"properties": {"fixed-nat-freed": {"minLength": 1, "maxLength": 255, "type": "string", "description": "Fixed-NAT freed (Custom message string. Should be in the format of \"MSGID [STRUCTURED-DATA] MSG\")", "format": "string-rlx"}, "port-batch-freed": {"minLength": 1, "maxLength": 255, "type": "string", "description": "Port Batch freed (Custom message string. Should be in the format of \"MSGID [STRUCTURED-DATA] MSG\")", "format": "string-rlx"}, "tech-type": {"enum": ["lsn", "nat64", "ds-lite", "sixrd-nat64"], "type": "string", "description": "'lsn': LSN; 'nat64': NAT64; 'ds-lite': DS-Lite; 'sixrd-nat64': 6rd-NAT64; ", "format": "enum"}, "fixed-nat-allocated": {"minLength": 1, "maxLength": 255, "type": "string", "description": "Fixed-NAT allocated (Custom message string. Should be in the format of \"MSGID [STRUCTURED-DATA] MSG\")", "format": "string-rlx"}, "port-allocated": {"minLength": 1, "maxLength": 255, "type": "string", "description": "Port allocated (Custom message string. Should be in the format of \"MSGID [STRUCTURED-DATA] MSG\")", "format": "string-rlx"}, "port-freed": {"minLength": 1, "maxLength": 255, "type": "string", "description": "Port freed (Custom message string. Should be in the format of \"MSGID [STRUCTURED-DATA] MSG\")", "format": "string-rlx"}, "optional": true, "port-batch-allocated": {"minLength": 1, "maxLength": 255, "type": "string", "description": "Port Batch allocated (Custom message string. Should be in the format of \"MSGID [STRUCTURED-DATA] MSG\")", "format": "string-rlx"}}}]}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "message"
        self.DeviceProxy = ""
        self.session_created = ""
        self.http_request_got = ""
        self.session_deleted = ""
        self.ipv6_tech = []

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class RfcCustom(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "rfc-custom"
        self.DeviceProxy = ""
        self.header = {}
        self.message = {}

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class HeaderCfg(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param custom_max_length: {"description": "Max length for a HTTP request log (Max header length (Default: 100 char))", "format": "number", "default": 100, "maximum": 1000, "minimum": 100, "type": "number"}
    :param http_header: {"enum": ["cookie", "referer", "user-agent", "header1", "header2", "header3"], "type": "string", "description": "'cookie': Log HTTP Cookie Header; 'referer': Log HTTP Referer Header; 'user-agent': Log HTTP User-Agent Header; 'header1': Log HTTP Header 1; 'header2': Log HTTP Header 2; 'header3': Log HTTP Header 3; ", "format": "enum"}
    :param custom_header_name: {"minLength": 1, "maxLength": 63, "type": "string", "description": "Header name", "format": "string"}
    :param max_length: {"description": "Max length for a HTTP request log (Max header length (Default: 100 char))", "format": "number", "default": 100, "maximum": 1000, "minimum": 100, "type": "number"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "header-cfg"
        self.DeviceProxy = ""
        self.custom_max_length = ""
        self.http_header = ""
        self.custom_header_name = ""
        self.max_length = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class IncludeHttp(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param header_cfg: {"minItems": 1, "items": {"type": "object"}, "uniqueItems": true, "type": "array", "array": [{"properties": {"custom-max-length": {"description": "Max length for a HTTP request log (Max header length (Default: 100 char))", "format": "number", "default": 100, "maximum": 1000, "minimum": 100, "type": "number"}, "http-header": {"enum": ["cookie", "referer", "user-agent", "header1", "header2", "header3"], "type": "string", "description": "'cookie': Log HTTP Cookie Header; 'referer': Log HTTP Referer Header; 'user-agent': Log HTTP User-Agent Header; 'header1': Log HTTP Header 1; 'header2': Log HTTP Header 2; 'header3': Log HTTP Header 3; ", "format": "enum"}, "optional": true, "custom-header-name": {"minLength": 1, "maxLength": 63, "type": "string", "description": "Header name", "format": "string"}, "max-length": {"description": "Max length for a HTTP request log (Max header length (Default: 100 char))", "format": "number", "default": 100, "maximum": 1000, "minimum": 100, "type": "number"}}}]}
    :param request_number: {"default": 0, "type": "number", "description": "HTTP Request Number", "format": "flag"}
    :param method: {"default": 0, "type": "number", "description": "Log the HTTP Request Method", "format": "flag"}
    :param l4_session_info: {"default": 0, "type": "number", "description": "Log the L4 session information of the HTTP request", "format": "flag"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "include-http"
        self.DeviceProxy = ""
        self.header_cfg = []
        self.request_number = ""
        self.method = ""
        self.l4_session_info = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class SourceAddress(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param ip: {"type": "string", "description": "Specify source IP address", "format": "ipv4-address"}
    :param ipv6: {"type": "string", "description": "Specify source IPv6 address", "format": "ipv6-address"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "source-address"
        self.DeviceProxy = ""
        self.ip = ""
        self.ipv6 = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class SourcePort(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param source_port_num: {"description": "Set source port for sending NAT syslogs (default: 514)", "format": "number", "default": 514, "maximum": 65535, "minimum": 1, "not": "any", "type": "number"}
    :param any: {"default": 0, "not": "source-port-num", "type": "number", "description": "Use any source port", "format": "flag"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "source-port"
        self.DeviceProxy = ""
        self.source_port_num = ""
        self.A10WW_any = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class UserPorts(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param start_time: {"type": "string", "description": "Time when periodic logging starts (Specify start time(hh:mm))", "format": "time-hhmm"}
    :param user_ports: {"default": 0, "type": "number", "description": "Log Fixed NAT User Ports Configured", "format": "flag"}
    :param days: {"description": "Specify period in days", "minimum": 1, "type": "number", "maximum": 30, "format": "number"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "user-ports"
        self.DeviceProxy = ""
        self.start_time = ""
        self.user_ports = ""
        self.days = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class FixedNat(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param fixed_nat_http_requests: {"enum": ["host", "url"], "type": "string", "description": "'host': Log the HTTP Host Header; 'url': Log the HTTP Request URL; ", "format": "enum"}
    :param fixed_nat_sessions: {"default": 0, "type": "number", "description": "Log all Fixed NAT sessions", "format": "flag"}
    :param fixed_nat_port_mappings: {"enum": ["both", "creation"], "type": "string", "description": "'both': Log creation and deletion of NAT mappings; 'creation': Log creation of NAT mappings; ", "format": "enum"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "fixed-nat"
        self.DeviceProxy = ""
        self.user_ports = {}
        self.fixed_nat_http_requests = ""
        self.fixed_nat_sessions = ""
        self.fixed_nat_port_mappings = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class Log(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param port_mappings: {"enum": ["creation", "disable"], "type": "string", "description": "'creation': Log only creation of NAT mappgins; 'disable': Disable Log creation and deletion of NAT mappings; ", "format": "enum"}
    :param port_overloading: {"default": 0, "type": "number", "description": "Force logging of all port-overloading sessions", "format": "flag"}
    :param http_requests: {"enum": ["host", "url"], "type": "string", "description": "'host': Log the HTTP Host Header; 'url': Log the HTTP Request URL; ", "format": "enum"}
    :param sessions: {"default": 0, "type": "number", "description": "Log all data sessions created using NAT", "format": "flag"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "log"
        self.DeviceProxy = ""
        self.port_mappings = ""
        self.port_overloading = ""
        self.fixed_nat = {}
        self.http_requests = ""
        self.sessions = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class Logging(A10BaseClass):
    
    """Class Description::
    Logging Template.

    Class logging supports CRUD Operations and inherits from `common/A10BaseClass`.
    This class is the `"PARENT"` class for this module.`

    :param include_partition_name: {"default": 0, "optional": true, "type": "number", "description": "Include partition name in logging events", "format": "flag"}
    :param batched_logging_disable: {"default": 0, "optional": true, "type": "number", "description": "Disable multiple logs per packet", "format": "flag"}
    :param name: {"description": "Logging template name", "format": "string-rlx", "minLength": 1, "optional": false, "maxLength": 63, "type": "string"}
    :param include_inside_user_mac: {"default": 0, "optional": true, "type": "number", "description": "Include the inside user MAC address in logs", "format": "flag"}
    :param facility: {"description": "'kernel': 0: Kernel; 'user': 1: User-level; 'mail': 2: Mail; 'daemon': 3: System daemons; 'security-authorization': 4: Security/authorization; 'syslog': 5: Syslog internal; 'line-printer': 6: Line printer; 'news': 7: Network news; 'uucp': 8: UUCP subsystem; 'cron': 9: Time-related; 'security-authorization-private': 10: Private security/authorization; 'ftp': 11: FTP; 'ntp': 12: NTP; 'audit': 13: Audit; 'alert': 14: Alert; 'clock': 15: Clock-related; 'local0': 16: Local use 0; 'local1': 17: Local use 1; 'local2': 18: Local use 2; 'local3': 19: Local use 3; 'local4': 20: Local use 4; 'local5': 21: Local use 5; 'local6': 22: Local use 6; 'local7': 23: Local use 7; ", "format": "enum", "default": "local0", "type": "string", "enum": ["kernel", "user", "mail", "daemon", "security-authorization", "syslog", "line-printer", "news", "uucp", "cron", "security-authorization-private", "ftp", "ntp", "audit", "alert", "clock", "local0", "local1", "local2", "local3", "local4", "local5", "local6", "local7"], "optional": true}
    :param include_destination: {"default": 0, "optional": true, "type": "number", "description": "Include the destination IP and port in logs", "format": "flag"}
    :param format: {"description": "'binary': Binary logging format; 'compact': Compact ASCII logging format (Hex format with compact representation); 'custom': Arbitrary custom logging format; 'default': Default A10 logging format (ASCII); 'rfc5424': RFC5424 compliant logging format; ", "format": "enum", "default": "default", "type": "string", "enum": ["binary", "compact", "custom", "default", "rfc5424"], "optional": true}
    :param service_group: {"description": "Set NAT logging service-group", "format": "string-rlx", "minLength": 1, "optional": true, "maxLength": 63, "type": "string"}
    :param shared: {"description": "Service group is in shared patition", "partition-visibility": "private", "default": 0, "type": "number", "format": "flag", "optional": true}
    :param resolution: {"description": "'seconds': Logging timestamp resolution in seconds (default); '10-milliseconds': Logging timestamp resolution in 10s of milli-seconds; ", "format": "enum", "default": "seconds", "type": "string", "enum": ["seconds", "10-milliseconds"], "optional": true}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    URL for this object::
    `https://<Hostname|Ip address>//axapi/v3/cgnv6/template/logging/{name}`.

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        self.required = [ "name"]

        self.b_key = "logging"
        self.a10_url="/axapi/v3/cgnv6/template/logging/{name}"
        self.DeviceProxy = ""
        self.include_partition_name = ""
        self.batched_logging_disable = ""
        self.log_receiver = {}
        self.name = ""
        self.include_inside_user_mac = ""
        self.facility = ""
        self.include_destination = ""
        self.severity = {}
        self.A10WW_format = ""
        self.include_radius_attribute = {}
        self.rule = {}
        self.custom = {}
        self.service_group = ""
        self.rfc_custom = {}
        self.include_http = {}
        self.source_address = {}
        self.shared = ""
        self.source_port = {}
        self.resolution = ""
        self.log = {}

        for keys, value in kwargs.items():
            setattr(self,keys, value)





from a10sdk.common.A10BaseClass import A10BaseClass


class ResourceUsage(A10BaseClass):
    
    """Class Description::
    Configure System Resource Usage.

    Class resource-usage supports CRUD Operations and inherits from `common/A10BaseClass`.
    This class is the `"PARENT"` class for this module.`

    :param l4_session_count: {"platform-specific-range": 1, "platform-specific-default": 1, "description": "Total Sessions in the System", "format": "number", "optional": true, "type": "number"}
    :param auth_portal_html_file_size: {"description": "Specify maximum html file size for http authentication", "format": "number", "default": 20, "optional": true, "maximum": 120, "minimum": 4, "type": "number"}
    :param auth_portal_image_file_size: {"description": "Specify maximum image file size for default portal", "format": "number", "default": 6, "optional": true, "maximum": 80, "minimum": 1, "type": "number"}
    :param max_aflex_file_size: {"description": "Set maximum aFleX file size (Maximum file size in KBytes, default is 32K)", "format": "number", "default": 32, "optional": true, "maximum": 256, "minimum": 16, "type": "number"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    URL for this object::
    `https://<Hostname|Ip address>//axapi/v3/system/resource-usage`.

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        self.required=[]
        self.b_key = "resource-usage"
        self.a10_url="/axapi/v3/system/resource-usage"
        self.DeviceProxy = ""
        self.l4_session_count = ""
        self.auth_portal_html_file_size = ""
        self.auth_portal_image_file_size = ""
        self.max_aflex_file_size = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)





from a10sdk.common.A10BaseClass import A10BaseClass


class Vip(A10BaseClass):
    
    """Class Description::
    Virtual IP (VIP).

    Class vip supports CRUD Operations and inherits from `common/A10BaseClass`.
    This class is the `"PARENT"` class for this module.`

    :param vip_map_list: {"minItems": 1, "items": {"type": "vip-map"}, "uniqueItems": true, "array": [{"required": ["vip-address"], "properties": {"floating-IP-forward-address": {"optional": true, "type": "string", "description": "Floating-IP as forward address. help-val Address", "format": "ipv4-address"}, "vip-address": {"optional": false, "type": "string", "description": "Address", "format": "ipv4-address"}}}], "type": "array", "$ref": "https://axapi.a10networks.com/axapi/v3/router/ospf/{process-id}/redistribute/vip/vip-map/{vip-address}"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    URL for this object::
    `https://<Hostname|Ip address>//axapi/v3/router/ospf/{process_id}/redistribute/vip`.

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        self.required=[]
        self.b_key = "vip"
        self.a10_url="/axapi/v3/router/ospf/{process_id}/redistribute/vip"
        self.DeviceProxy = ""
        self.vip_map_list = []
        self.vip_redist = {}

        for keys, value in kwargs.items():
            setattr(self,keys, value)





from a10sdk.common.A10BaseClass import A10BaseClass


class Source(A10BaseClass):
    
    """Class Description::
    Source Association.

    Class source supports CRUD Operations and inherits from `common/A10BaseClass`.
    This class is the `"PARENT"` class for this module.`

    :param list_list: {"minItems": 1, "items": {"type": "list"}, "uniqueItems": true, "array": [{"required": ["list-name"], "properties": {"list-name": {"description": "IPv6 access-list name", "format": "string", "minLength": 1, "optional": false, "maxLength": 16, "type": "string", "$ref": "/axapi/v3/ipv6/access-list"}, "pool": {"description": "IPv6 NAT Pool (Pool Name)", "format": "string-rlx", "minLength": 1, "optional": true, "maxLength": 63, "type": "string", "$ref": "/axapi/v3/ipv6/nat/pool-group"}}}], "type": "array", "$ref": "/axapi/v3/ipv6/nat/inside/source/list/{list-name}"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    URL for this object::
    `https://<Hostname|Ip address>//axapi/v3/ipv6/nat/inside/source`.

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        self.required=[]
        self.b_key = "source"
        self.a10_url="/axapi/v3/ipv6/nat/inside/source"
        self.DeviceProxy = ""
        self.list_list = []

        for keys, value in kwargs.items():
            setattr(self,keys, value)


